# OZI CHANGELOG
## 1.20.1 (2024-08-30)


### ⬆️ Upgraded Dependencies

*  Update ozi-core requirement from ~=0.3.1 to ~=1.0.6


updated-dependencies:
- dependency-name: ozi-core
  dependency-type: direct:production
... — dependabot[bot] &lt;support@github.com&gt;
([`24adff3`](https://github.com/OZI-Project/OZI/commit/24adff32caaf773709e616af4d452b93a4813def))

*  Bump github/codeql-action from 3.26.5 to 3.26.6

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.26.5 to 3.26.6.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/2c779ab0d087cd7fe7b826087247c2c81f27bfa6...4dd16135b69a43b6c8efb853346f8437d92d3c93)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`3e84044`](https://github.com/OZI-Project/OZI/commit/3e84044ce8a9aef594170c903e1369f96c46304b))

## 1.20.0 (2024-08-29)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.26.4 to 3.26.5

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.26.4 to 3.26.5.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/f0f3afee809481da311ca3a6ff1ff51d81dbeb24...2c779ab0d087cd7fe7b826087247c2c81f27bfa6)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`d67a23f`](https://github.com/OZI-Project/OZI/commit/d67a23f5c14dc96405677b6ddc7cde7f70394096))


### 🐛 Fixed Bugs

*  add length() check to deps install
([`c223d71`](https://github.com/OZI-Project/OZI/commit/c223d71c118d1dfac26b98d59307b23dc672bf94))

*  add length() check to deps install — rjdbcm &lt;ozi.project@outlook.com&gt;
([`5f2b441`](https://github.com/OZI-Project/OZI/commit/5f2b4411e03ac6cbb54ffdbdf19c342e6e7f6fe4))

*  revert: fix postconf install script copy on configure — rjdbcm &lt;ozi.project@outlook.com&gt;
([`29b7b00`](https://github.com/OZI-Project/OZI/commit/29b7b00d0f8d497d8c22144cc54ba8055f9c6739))

*  fix postconf install script copy on configure — rjdbcm &lt;ozi.project@outlook.com&gt;
([`1674d2b`](https://github.com/OZI-Project/OZI/commit/1674d2b130d62e9bee19f6bedee1f70deb456e95))

*  set variable install_dependencies in meson — rjdbcm &lt;ozi.project@outlook.com&gt;
([`a591db2`](https://github.com/OZI-Project/OZI/commit/a591db279ac2fd952ffa7b3c9b63cc25de9f1148))

*  set variable install_dependencies in meson — rjdbcm &lt;ozi.project@outlook.com&gt;
([`f6faa33`](https://github.com/OZI-Project/OZI/commit/f6faa3331d575567921e9997fe7438bffba4e8ff))

*  revert the revert — rjdbcm &lt;ozi.project@outlook.com&gt;
([`5951997`](https://github.com/OZI-Project/OZI/commit/5951997fd2bc059cd6be94299322d414509120de))

*  revert METADATA unlink — rjdbcm &lt;ozi.project@outlook.com&gt;
([`1755bd7`](https://github.com/OZI-Project/OZI/commit/1755bd777c57404200d689ce23042bb97c44dab6))


### 🚸 Improved Usability

*  backward compatible fix for OZI.build 1.3+ — rjdbcm &lt;ozi.project@outlook.com&gt;
([`cae39ae`](https://github.com/OZI-Project/OZI/commit/cae39ae8db622373351a59203eb7813dcd18e08e))


### ✨ Implemented Features

*  use OZI.build 1.4

moves all metadata into project and tool.ozi-build — rjdbcm &lt;ozi.project@outlook.com&gt;
([`ff8aa92`](https://github.com/OZI-Project/OZI/commit/ff8aa92a9c63063c6730c28c8b3747ab98d9ebe3))


### Other


* 🚨 run black — rjdbcm &lt;ozi.project@outlook.com&gt;
([`a681472`](https://github.com/OZI-Project/OZI/commit/a6814720fd832edc84278561970f13bf9ce0f01d))

* fix: add new style dep install — rjdbcm &lt;ozi.project@outlook.com&gt;
([`503364e`](https://github.com/OZI-Project/OZI/commit/503364e74dc9a90b5a943e5dcde9296963588cec))

## 1.19.2 (2024-08-24)


### ⬆️ Upgraded Dependencies

*  ozi-core~=0.3.1 — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`d37e527`](https://github.com/OZI-Project/OZI/commit/d37e527afc9c277d598213a455864e3b7bdfcb27))

*  Bump OZI-Project/draft from 0.3.8 to 0.3.9

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.8 to 0.3.9.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/38dfc0df2b189018bbae0b016c61ac1d704c2626...d9421ff8095e084639f3b03673b110033452c9e0)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`3ef9970`](https://github.com/OZI-Project/OZI/commit/3ef997053ef6ec0d6cb61c230e8bf100b6aee2ab))

## 1.19.1 (2024-08-23)


### 🐛 Fixed Bugs

*  fix invoke call — rjdbcm &lt;ozi.project@outlook.com&gt;
([`7e33e8e`](https://github.com/OZI-Project/OZI/commit/7e33e8e715a832b3eef2d63b37500295d3a0c923))

*  fix invoke setup call ozi bootstrap — rjdbcm &lt;ozi.project@outlook.com&gt;
([`47e3e15`](https://github.com/OZI-Project/OZI/commit/47e3e1593ac92df036d6c8f83c90617341f9da5b))

*  turn off blastpipe for now — rjdbcm &lt;ozi.project@outlook.com&gt;
([`880ad78`](https://github.com/OZI-Project/OZI/commit/880ad78f23eb871b7f17687a7e3d697ee48e4b73))

*  fix invoke meson option setting — rjdbcm &lt;ozi.project@outlook.com&gt;
([`c8bedb4`](https://github.com/OZI-Project/OZI/commit/c8bedb4563afe03d94f297bb5070fa14d74c343b))


### 🏷️


*  pyright fixes — rjdbcm &lt;ozi.project@outlook.com&gt;
([`972be3c`](https://github.com/OZI-Project/OZI/commit/972be3c368a42086243ffbf8c9480a1a431763d4))


### Other


* 🚨 run black — rjdbcm &lt;ozi.project@outlook.com&gt;
([`f572c2d`](https://github.com/OZI-Project/OZI/commit/f572c2df50a63bac02d0a238c39085c19addb926))

## 1.19.0 (2024-08-23)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.26.2 to 3.26.4

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.26.2 to 3.26.4.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/429e1977040da7a23b6822b13c129cd1ba93dbb2...f0f3afee809481da311ca3a6ff1ff51d81dbeb24)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`1f42519`](https://github.com/OZI-Project/OZI/commit/1f42519ed48456ab34ed1604887e76dd904545c4))

*  Bump OZI-Project/publish from 0.1.9 to 0.1.10

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.9 to 0.1.10.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/e53fb3caac6d0530d1cc3d05d0c3e3a6b6fb1c67...cc463a2e9d2e928559e3edb4bd7f0fbcbefd1f11)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`46bbcfa`](https://github.com/OZI-Project/OZI/commit/46bbcfa17229a34e705dc9cbff92be4f3e153dac))

*  Bump OZI-Project/release from 0.8.9 to 0.8.10

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.8.9 to 0.8.10.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/f4172eb60419c98b5cf18c89d78cde8b553f5d15...7edb07c74e124270a29b2cd5d32ce7c9fdfc0b22)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`766723b`](https://github.com/OZI-Project/OZI/commit/766723bf834209690744443ad615eb7de423ab93))

*  Bump OZI-Project/checkpoint from 0.5.1 to 0.5.2

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.5.1 to 0.5.2.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/bfd6e529455ff6ec099bfd16be2ab86fa0332a71...cd1117d2d6d352e52d9dfdb603b8ebd7ef964908)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`d9bc0ae`](https://github.com/OZI-Project/OZI/commit/d9bc0ae90e0b4a578a9e67c939e51c4da2f2e206))


### 🔨 Updated Scripts

*  clean up requirements for ozi-core 0.3 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`645cc12`](https://github.com/OZI-Project/OZI/commit/645cc129df27bc254b587cfb7289685fab13a104))

*  finalize tasks.py — rjdbcm &lt;ozi.project@outlook.com&gt;
([`788d0a4`](https://github.com/OZI-Project/OZI/commit/788d0a4b5b40392393dfd6b96244df7845ba945b))


### ✨ Implemented Features

*  add invoke tasks and improve tox entrypoints

Using the invoke backend speeds up our checkpoints by 30%.
ozi-spec 0.7 adds invoke to build-system dependencies.
ozi-templates 2.9 improves tox checkpoint testenvs to use invoke and improved support for uv.
Prior to now pip installed all dependencies for tox checkpoints, even with ``--enable-uv``. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`f6b0982`](https://github.com/OZI-Project/OZI/commit/f6b098240a5aee34db5d7002383d74d56ad700f9))

## 1.18.6 (2024-08-18)


### ⬆️ Upgraded Dependencies

*  update ozi-core requirement from ~=0.2.3 to ~=0.2.4 — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`808016b`](https://github.com/OZI-Project/OZI/commit/808016b1127e29eac83c49a7c14a925890fd4d2d))

## 1.18.5 (2024-08-18)


### ⬆️ Upgraded Dependencies

*  update ozi-core requirement from ~=0.2.2 to ~=0.2.3 — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`eb17028`](https://github.com/OZI-Project/OZI/commit/eb17028143ebab42015820fe663e696dcb7a25f0))

## 1.18.4 (2024-08-17)


### 🐛 Fixed Bugs

*  Merge pull request #1030 from OZI-Project/release/1.18

Release/1.18
([`b703a70`](https://github.com/OZI-Project/OZI/commit/b703a707df8fffa4d974da0daabe01d78010e0ae))

*  fix pip path get — rjdbcm &lt;ozi.project@outlook.com&gt;
([`f61033e`](https://github.com/OZI-Project/OZI/commit/f61033ed22a8f404c68e729eb109ea6c99ce11d7))

## 1.18.3 (2024-08-17)


### 🐛 Fixed Bugs

*  fix backward compatibility with non-uv packages — rjdbcm &lt;ozi.project@outlook.com&gt;
([`e343072`](https://github.com/OZI-Project/OZI/commit/e343072754b61e98acb21f73765e3bd2aa644512))

## 1.18.2 (2024-08-17)


### 🐛 Fixed Bugs

*  fix uv backend fallback to pip-tools — rjdbcm &lt;ozi.project@outlook.com&gt;
([`c548e87`](https://github.com/OZI-Project/OZI/commit/c548e8732913f8777d05d71333ea76b608381497))

## 1.18.1 (2024-08-17)


### 🐛 Fixed Bugs

*  fix missing pip subcommands — rjdbcm &lt;ozi.project@outlook.com&gt;
([`8f6ea9b`](https://github.com/OZI-Project/OZI/commit/8f6ea9bf46115d18aee97682014667b394d3cc2f))

## 1.18.0 (2024-08-16)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.26.1 to 3.26.2

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.26.1 to 3.26.2.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/29d86d22a34ea372b1bbf3b2dced2e25ca6b3384...429e1977040da7a23b6822b13c129cd1ba93dbb2)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`5f2df5e`](https://github.com/OZI-Project/OZI/commit/5f2df5eca276088a3656b259923f2fb7d50b7a2c))

## 1.17.20 (2024-08-15)


### ⬆️ Upgraded Dependencies

*  Update ozi-core requirement from ~=0.1.21 to ~=0.2.2


updated-dependencies:
- dependency-name: ozi-core
  dependency-type: direct:production
... — dependabot[bot] &lt;support@github.com&gt;
([`06f02f7`](https://github.com/OZI-Project/OZI/commit/06f02f75da2095dce749f653d86186e1f0d742e4))

*  invoke~=2.2 over 2.0 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`1a2a795`](https://github.com/OZI-Project/OZI/commit/1a2a7951032c23a22e35a63098f5c4b7b622c43c))


### 🔨 Updated Scripts

* (requirements/sigstore): add ``--prerelease=allow`` if using ``uv`` — rjdbcm &lt;ozi.project@outlook.com&gt;
([`531176e`](https://github.com/OZI-Project/OZI/commit/531176e5fb2a0aaf7614c505ca7d7524bef40270))


### 🏷️


*  ``type: ignore`` on ``invoke.call`` — rjdbcm &lt;ozi.project@outlook.com&gt;
([`955a299`](https://github.com/OZI-Project/OZI/commit/955a2996b00622cde87d804ffe01c1a120bd1830))


### ✏️ Corrected Typos

*  add missing build assets — rjdbcm &lt;ozi.project@outlook.com&gt;
([`3c29987`](https://github.com/OZI-Project/OZI/commit/3c29987f9ab2eb592fdc285d086fd1ab48868293))


### ✨ Implemented Features

*  OZI spec 0.6

Adds cibuildwheel and twine and dist plugins. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`66a7f90`](https://github.com/OZI-Project/OZI/commit/66a7f900ef6b2f752c27688b7dfb41ec2d8ea069))


### 🔨 Updated Configuration

* (tox) add testenv dep ``uv`` — rjdbcm &lt;ozi.project@outlook.com&gt;
([`f73b37b`](https://github.com/OZI-Project/OZI/commit/f73b37b88341d6ee7a79e725c81a93a1d18ced28))

*  Development Status :: 4 - Beta — rjdbcm &lt;ozi.project@outlook.com&gt;
([`9313ea6`](https://github.com/OZI-Project/OZI/commit/9313ea60f86e7bc43170675e4cec4c8cfdd98c91))

## 1.17.19 (2024-08-15)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.26.0 to 3.26.1

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.26.0 to 3.26.1.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/eb055d739abdc2e8de2e5f4ba1a8b246daa779aa...29d86d22a34ea372b1bbf3b2dced2e25ca6b3384)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`57baab1`](https://github.com/OZI-Project/OZI/commit/57baab185518cd4203e65a9f2ec12e5f75d58352))


### 🔨 Updated Scripts

* 🔧 add invoke tasks to tox CI/CD setup for self-hosted publishing. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`e0550e2`](https://github.com/OZI-Project/OZI/commit/e0550e232dac9c0cc99630de523e408da323d98f))

*  add SLSA dependency wrapfile — rjdbcm &lt;ozi.project@outlook.com&gt;
([`68c5f71`](https://github.com/OZI-Project/OZI/commit/68c5f7118a7a17dc0a2ef25057811e32d37c1cbe))


### ➕ Added Dependencies

*  invoke~=2.0, types-invoke~=2.0 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`6512849`](https://github.com/OZI-Project/OZI/commit/65128497fde9e5200bbda3daf981b40dd793a709))

## 1.17.18 (2024-08-13)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/release from 0.8.5 to 0.8.9

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.8.5 to 0.8.9.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/b4279d73f1dff27e0c651f95ca20bc753b889ca9...f4172eb60419c98b5cf18c89d78cde8b553f5d15)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`33f19c0`](https://github.com/OZI-Project/OZI/commit/33f19c0288318b7cb8959b77f49d63b02d49c17b))


### 📌 Pinned Dependencies

*  ozi-core~=0.1.21 — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`f8ae848`](https://github.com/OZI-Project/OZI/commit/f8ae8485f04760b92f7c5b50e10fb19166f9f9ff))

## 1.17.17 (2024-08-12)


### 📌 Pinned Dependencies

*  ozi-core~=0.1.19

Cleans up calls to ``TAP.diagnostic``. — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`025cc95`](https://github.com/OZI-Project/OZI/commit/025cc95c600c7fea02a174463eb8aac3e82236bc))

## 1.17.16 (2024-08-11)


### 📌 Pinned Dependencies

*  ozi-core~=0.1.18 — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`5d9cabd`](https://github.com/OZI-Project/OZI/commit/5d9cabd96387ce9f9762ba4ab4c78170fe119d00))

## 1.17.15 (2024-08-11)


### ⬆️ Upgraded Dependencies

*  OZI-Project/release@0.8.5 — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`aa7a586`](https://github.com/OZI-Project/OZI/commit/aa7a586f3ffe20a235ebc65583b07f050bc4e29d))


### 🔨 Updated Scripts

*  add quay.io to allowed release endpoints — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`50269d7`](https://github.com/OZI-Project/OZI/commit/50269d774ec005342b115e19294b288b772140c4))

## 1.17.14 (2024-08-11)


### ⬆️ Upgraded Dependencies

*  Bump actions/upload-artifact from 4.3.5 to 4.3.6

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.3.5 to 4.3.6.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/89ef406dd8d7e03cfd12d9e0a4a378f454709029...834a144ee995460fba8ed112a2fc961b36a5ec5a)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`7662e60`](https://github.com/OZI-Project/OZI/commit/7662e60edd475a182c6b4a0d8ada46dd15d9425a))

*  Bump OZI-Project/draft from 0.3.7 to 0.3.8

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.7 to 0.3.8.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/f9e3ee38f76e3aefcbf29743e9ec64f716182001...38dfc0df2b189018bbae0b016c61ac1d704c2626)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`70c608e`](https://github.com/OZI-Project/OZI/commit/70c608e50ac806c531b302d519e29c42feedaa0f))

*  Bump OZI-Project/checkpoint from 0.5.0 to 0.5.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.5.0 to 0.5.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/8b8d7d173139c115188e4689204aba4e36e98810...bfd6e529455ff6ec099bfd16be2ab86fa0332a71)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`623829d`](https://github.com/OZI-Project/OZI/commit/623829d33c9cc85bf3b4c48a586410d7bab1bb95))

*  Bump OZI-Project/release from 0.7.3 to 0.8.4

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.7.3 to 0.8.4.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/b2388e2a058926646944ddc471737e2e6495940d...0ca87b5495c672f0d0c5ceaa6508e631a5c051f9)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`249838e`](https://github.com/OZI-Project/OZI/commit/249838e1abd5d8ac26cfe7e935199c2e62b674a5))

*  Update ozi-core requirement from ~=0.1.15 to ~=0.1.17


updated-dependencies:
- dependency-name: ozi-core
  dependency-type: direct:production
... — dependabot[bot] &lt;support@github.com&gt;
([`244f79c`](https://github.com/OZI-Project/OZI/commit/244f79c0a00db6acaebab271dc62118b89a6fc29))

*  Bump github/codeql-action from 3.25.15 to 3.26.0

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.15 to 3.26.0.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/afb54ba388a7dca6ecae48f608c4ff05ff4cc77a...eb055d739abdc2e8de2e5f4ba1a8b246daa779aa)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`3e7d549`](https://github.com/OZI-Project/OZI/commit/3e7d549cbbba88e7629afb6b1c5505f5ff54a1ee))

*  Bump step-security/harden-runner from 2.9.0 to 2.9.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.9.0 to 2.9.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/0d381219ddf674d61a7572ddd19d7941e271515c...5c7944e73c4c2a096b17a9cb74d65b6c2bbafbde)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`24acd17`](https://github.com/OZI-Project/OZI/commit/24acd17d609ee950157c7d26f60b6de0a4869156))

*  black~=24.8.0 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`7160880`](https://github.com/OZI-Project/OZI/commit/7160880e3bb5614a9a76ed24e2cd647f9acab1d4))


### 📌 Pinned Dependencies

*  hypothesis[all]~=6.108 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`3858c0b`](https://github.com/OZI-Project/OZI/commit/3858c0b85e3809b1a21e87481b7b364acf7cca49))

*  urllib3~=1.26 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`327de11`](https://github.com/OZI-Project/OZI/commit/327de11e3072bc40098a31519b9138279b909051))

*  pytest-xdist~=3.6 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`1dd1eed`](https://github.com/OZI-Project/OZI/commit/1dd1eed4949475f4ef0bfcb230ed187fc7ee5f46))

*  pytest-tcpclient~=0.7 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`9286a08`](https://github.com/OZI-Project/OZI/commit/9286a081a3d1dd7986f18d9da6f06f44aab7babb))

*  pytest-randomly~=3.15 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`32dbfa5`](https://github.com/OZI-Project/OZI/commit/32dbfa5edaf81af8b060b46506b7d5f49dd12011))

*  pytest-cov~=5.0 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`a33aebe`](https://github.com/OZI-Project/OZI/commit/a33aebe4297a3c0c26a06b3ab0b12d7f6f26cd4a))

*  pytest-asyncio&gt;=0.23.8 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`a63cd1b`](https://github.com/OZI-Project/OZI/commit/a63cd1bdb6683466587053fe2c925920671b25b6))

*  pytest~=8.3 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`8ec1e9f`](https://github.com/OZI-Project/OZI/commit/8ec1e9f00aafda87872c5b60505a6705b53a2d69))

*  sigstore~=3.1 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`4365fb6`](https://github.com/OZI-Project/OZI/commit/4365fb68b03c36d64306b64260751e79d12c0a06))

*  python-semantic-release~=9.8 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`15035cb`](https://github.com/OZI-Project/OZI/commit/15035cb466b85d7ad27ea3eae359ce52af74de00))

*  coverage[toml]~=7.6 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`d44d07f`](https://github.com/OZI-Project/OZI/commit/d44d07f8f051c3df97ca092f22c10112bbf406a9))

*  flake8-pyi~=24.6 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`a99849e`](https://github.com/OZI-Project/OZI/commit/a99849e5486da255003d5f59080957ff93889096))

*  flake8-tidy-imports~=4.10 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`59b1e37`](https://github.com/OZI-Project/OZI/commit/59b1e3741a8f989ee17517581034749b422baeef))

*  flake8-leading-blank-lines~=1.0 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`b17ae4a`](https://github.com/OZI-Project/OZI/commit/b17ae4a102c5653ed016b5593259b5b9f0266ddf))

*  flake8-comprehensions~=3.15 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`8df75ee`](https://github.com/OZI-Project/OZI/commit/8df75ee1b05dd4bc5efc5175d32fff4743fa9c78))

*  flake8-no-pep420~=2.7 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`d70e1a4`](https://github.com/OZI-Project/OZI/commit/d70e1a419e8795cd82a1a289c41c2a0676b00db4))

*  flake8-datetimez~=20.10 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`b65325f`](https://github.com/OZI-Project/OZI/commit/b65325f09b7973131fdfb05a959b94e55ea0361b))

*  flake8-bugbear~=24.4 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`a6a2484`](https://github.com/OZI-Project/OZI/commit/a6a2484b3818bceae1c7dba2db071451c129fdf5))

*  flake8-fixme~=1.1 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`1d5f40d`](https://github.com/OZI-Project/OZI/commit/1d5f40d0cc021d20c3e95c6de792f2bd1e9fd733))

*  flake8-eradicate~=1.5 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`d006831`](https://github.com/OZI-Project/OZI/commit/d006831019459f89e9f264dd311546e63f38a009))

*  flake8-broken-line~=1.0 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`37be826`](https://github.com/OZI-Project/OZI/commit/37be826270bc8dfd6e300c5ef3219e0e450c4464))

*  flake8-annotations~=3.1 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`804c2cb`](https://github.com/OZI-Project/OZI/commit/804c2cbf262abc75e9a4305bc3ce1dd48bc5e379))

*  flake8-type-checking~=2.9 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`888de0f`](https://github.com/OZI-Project/OZI/commit/888de0fa698afb4437998188e869df97bd698983))

*  flake8-pytest-style~=2.0 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`562e782`](https://github.com/OZI-Project/OZI/commit/562e782923c68c1672bbeb1b5378cb8f30c6075a))

*  bandit[toml]~=1.7 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`374fe90`](https://github.com/OZI-Project/OZI/commit/374fe90bbccff95970d9506a279929441de5d40d))

*  flake8-quotes~=3.4 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`ea8b400`](https://github.com/OZI-Project/OZI/commit/ea8b4009f6f863846593e17e9c082158aff0afe6))

*  flake8~=7.1 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`3137752`](https://github.com/OZI-Project/OZI/commit/31377521ee6d5e1b1814fdff59f05e72ea3794f7))

*  Flake8-pyproject~=1.2 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`8e5898d`](https://github.com/OZI-Project/OZI/commit/8e5898d7061608f1a8324974cc8f82dd20d08e5a))

## 1.17.13 (2024-08-04)

## 1.17.12 (2024-08-04)

## 1.17.11 (2024-08-04)

## 1.17.10 (2024-08-04)


### ⬆️ Upgraded Dependencies

*  Bump actions/upload-artifact from 4.3.4 to 4.3.5

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.3.4 to 4.3.5.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/0b2256b8c012f0828dc542b3febcab082c67f72b...89ef406dd8d7e03cfd12d9e0a4a378f454709029)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`898fee4`](https://github.com/OZI-Project/OZI/commit/898fee49f18635db5c6fcc2dffdeb573524dbe59))


### 🐛 Fixed Bugs

*  normalize ``semantic-release`` before checking version — rjdbcm &lt;ozi.project@outlook.com&gt;
([`9a92d58`](https://github.com/OZI-Project/OZI/commit/9a92d584e7f0533517649e273a03989ca7002ed2))

*  semantic-release name normalized — rjdbcm &lt;ozi.project@outlook.com&gt;
([`56d7331`](https://github.com/OZI-Project/OZI/commit/56d733154ada561326e9ab4d6442f69bbeb02474))

## 1.17.9 (2024-08-01)

## 1.17.8 (2024-08-01)

## 1.17.7 (2024-08-01)

## 1.17.6 (2024-08-01)


### 🐛 Fixed Bugs

*  fix name normalization of ``python-semantic-release`` — rjdbcm &lt;ozi.project@outlook.com&gt;
([`bd5d080`](https://github.com/OZI-Project/OZI/commit/bd5d0808aa948c96c3fda6add0ab9bc3cd2f65e3))

*  normalize ``python-semantic-release`` to ``semantic_release`` for ``install-args`` — rjdbcm &lt;ozi.project@outlook.com&gt;
([`fa0d457`](https://github.com/OZI-Project/OZI/commit/fa0d4570f9d4e975c83c6601627cdda6af674df7))

* (meson.options): add ``flake8-docstring-checker`` to ``plugin-only`` — rjdbcm &lt;ozi.project@outlook.com&gt;
([`b69ee5c`](https://github.com/OZI-Project/OZI/commit/b69ee5c346d4155101b1686f2d6dbff4f4b841df))

*  normalize ``semantic-release`` to ``semantic_release`` — rjdbcm &lt;ozi.project@outlook.com&gt;
([`351327c`](https://github.com/OZI-Project/OZI/commit/351327c23be354aebece120bf3114630bb0e5f85))

*  Merge pull request #965 from OZI-Project/release/1.17

Merge pull request #964 from OZI-Project/main
([`ee9db56`](https://github.com/OZI-Project/OZI/commit/ee9db561c2f6d1e326a5ac30063a9427abc316d0))

## 1.17.5 (2024-08-01)

## 1.17.4 (2024-07-31)

## 1.17.3 (2024-07-29)


### ⬆️ Upgraded Dependencies

*  Update ozi-core requirement from ~=0.1.14 to ~=0.1.15


updated-dependencies:
- dependency-name: ozi-core
  dependency-type: direct:production
... — dependabot[bot] &lt;support@github.com&gt;
([`7ea2e52`](https://github.com/OZI-Project/OZI/commit/7ea2e52bfd4094183a17d4012acfcdeb7c997c2e))

*  Bump ossf/scorecard-action from 2.3.3 to 2.4.0

Bumps [ossf/scorecard-action](https://github.com/ossf/scorecard-action) from 2.3.3 to 2.4.0.
- [Release notes](https://github.com/ossf/scorecard-action/releases)
- [Changelog](https://github.com/ossf/scorecard-action/blob/main/RELEASE.md)
- [Commits](https://github.com/ossf/scorecard-action/compare/dc50aa9510b46c811795eb24b2f1ba02a914e534...62b2cac7ed8198b15735ed49ab1e5cf35480ba46)


updated-dependencies:
- dependency-name: ossf/scorecard-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`e2a9a3c`](https://github.com/OZI-Project/OZI/commit/e2a9a3c155de39a932b606af25e81ddaa6f1b36a))

*  Update ozi-core requirement from ~=0.1.12 to ~=0.1.14


updated-dependencies:
- dependency-name: ozi-core
  dependency-type: direct:production
... — dependabot[bot] &lt;support@github.com&gt;
([`790c68f`](https://github.com/OZI-Project/OZI/commit/790c68f8b38eda325c21fbe5a66f30d95cb59c41))

*  Bump github/codeql-action from 3.25.14 to 3.25.15

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.14 to 3.25.15.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/5cf07d8b700b67e235fbb65cbc84f69c0cf10464...afb54ba388a7dca6ecae48f608c4ff05ff4cc77a)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`4d7b7f4`](https://github.com/OZI-Project/OZI/commit/4d7b7f4dc5839b6b121f032f097584a066fa0f38))

*  Bump github/codeql-action from 3.25.13 to 3.25.14

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.13 to 3.25.14.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/2d790406f505036ef40ecba973cc774a50395aac...5cf07d8b700b67e235fbb65cbc84f69c0cf10464)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`311dc09`](https://github.com/OZI-Project/OZI/commit/311dc095881d22a3f46965d76371c83f0b22aa0c))


### 🐛 Fixed Bugs

*  fix semantic-release command name mismatch — rjdbcm &lt;ozi.project@outlook.com&gt;
([`9116e83`](https://github.com/OZI-Project/OZI/commit/9116e836f066e3fddc200c9f32f0c59178e8588a))


### Other


* Update dependabot.yml — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`bdf063f`](https://github.com/OZI-Project/OZI/commit/bdf063f075c90dc46af4f6190218aad867f6e35c))

## 1.17.2 (2024-07-25)

## 1.17.1 (2024-07-23)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/publish from 0.1.8 to 0.1.9

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.8 to 0.1.9.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/798954a5a38220573d0a8c2873b5b08d1059d237...e53fb3caac6d0530d1cc3d05d0c3e3a6b6fb1c67)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`8308bb9`](https://github.com/OZI-Project/OZI/commit/8308bb9c82d4a34247c0e4c27bcd44a4527a929f))

*  Bump OZI-Project/draft from 0.3.6 to 0.3.7

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.6 to 0.3.7.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/29d09f8b7b490a3be3b6a448f1f40864fe1c7b25...f9e3ee38f76e3aefcbf29743e9ec64f716182001)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`2526a71`](https://github.com/OZI-Project/OZI/commit/2526a71e22333f39598d8d82f47a82fdc26facd2))

*  Bump github/codeql-action from 3.25.12 to 3.25.13

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.12 to 3.25.13.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/4fa2a7953630fd2f3fb380f21be14ede0169dd4f...2d790406f505036ef40ecba973cc774a50395aac)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`5b14348`](https://github.com/OZI-Project/OZI/commit/5b143481afe6096253db33bb742a4150573d6c6c))


### 🐛 Fixed Bugs

* (meson.options): yield dependencies and suite settings to superproject — rjdbcm &lt;ozi.project@outlook.com&gt;
([`1221540`](https://github.com/OZI-Project/OZI/commit/12215404dc362bd7a4ad94e6fc18b01ba8bd93ed))

*  fix broken changelog templates — rjdbcm &lt;ozi.project@outlook.com&gt;
([`00ed9f0`](https://github.com/OZI-Project/OZI/commit/00ed9f003957018ea9487f20aed4c3b6703a1786))


### 🏷️


*  add type ignore to main entrypoints — rjdbcm &lt;ozi.project@outlook.com&gt;
([`79e1534`](https://github.com/OZI-Project/OZI/commit/79e15341d48039b3199010a4544ffe2241e75c6b))


### 📌 Pinned Dependencies

*  pip-tools~=7.4 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`cfdbe44`](https://github.com/OZI-Project/OZI/commit/cfdbe44f5bfed1fbd358f4aad82cd336ae309762))

*  ozi-core~=0.1.12 removed pins for all other core libs — rjdbcm &lt;ozi.project@outlook.com&gt;
([`2f768ac`](https://github.com/OZI-Project/OZI/commit/2f768ac8acac9f233268db6a14e21bd021cbeb58))


### Other


* :fix:(meson.options): ``python-dependencies`` shouldnt yield to superproject — rjdbcm &lt;ozi.project@outlook.com&gt;
([`f31d1e1`](https://github.com/OZI-Project/OZI/commit/f31d1e1a62d6f84d28e1a372dcf802b8fec0bba7))

## 1.17.0 (2024-07-21)


### ✨ Implemented Features

* 🐛 sigstore-v3 forces a minor version bump — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`8f8fa88`](https://github.com/OZI-Project/OZI/commit/8f8fa885491d718d87013e75ed96b704037ac9d8))

## 1.16.15 (2024-07-19)


### ⬆️ Upgraded Dependencies

*  Bump step-security/harden-runner from 2.8.1 to 2.9.0

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.8.1 to 2.9.0.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/17d0e2bd7d51742c71671bd19fa12bdc9d40a3d6...0d381219ddf674d61a7572ddd19d7941e271515c)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`9871f40`](https://github.com/OZI-Project/OZI/commit/9871f40be8a2aebc95b5953dabe2dba17d20019d))

*  Bump OZI-Project/draft from 0.3.5 to 0.3.6

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.5 to 0.3.6.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/8b8bafcce0442b4f6985d364c27030e44648e998...29d09f8b7b490a3be3b6a448f1f40864fe1c7b25)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`3ed3eb9`](https://github.com/OZI-Project/OZI/commit/3ed3eb9cbd5c9c4277bd31f0e3ebc302307b1394))

*  Bump OZI-Project/checkpoint from 0.4.3 to 0.5.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.4.3 to 0.5.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/bfd00dbaebfc8e86f730575dd907eb043052e795...8b8d7d173139c115188e4689204aba4e36e98810)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`f92a737`](https://github.com/OZI-Project/OZI/commit/f92a737f91db1d34b2da1b9293cf71aa9d63d69f))

*  Bump OZI-Project/release from 0.6.6 to 0.7.3

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.6.6 to 0.7.3.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/de8cb06cabbdc0697678bb16091258e8cc2e8f34...b2388e2a058926646944ddc471737e2e6495940d)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`51addab`](https://github.com/OZI-Project/OZI/commit/51addabc90fd4e64e0135c6f9030d313e66cdb17))


### 🚸 Improved Usability

*  use sigstore-v3 workflows in github CI — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`fa2ffd5`](https://github.com/OZI-Project/OZI/commit/fa2ffd520f349e39a15090e2cbf3e28487a45e05))

## 1.16.14 (2024-07-18)


### 🐛 Fixed Bugs

* 📌 fix wheel tags with OZI.build&gt;=0.0.27 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`c49ad41`](https://github.com/OZI-Project/OZI/commit/c49ad41d938d2042a4f7052c8b4f4b96af970617))


### 📌 Pinned Dependencies

*  TAP-Producer~=0.1.3 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`dd0c6c0`](https://github.com/OZI-Project/OZI/commit/dd0c6c0b6677685357ea5efe2a55e2a84309611a))

## 1.16.13 (2024-07-18)

## 1.16.12 (2024-07-14)


### 📌 Pinned Dependencies

*  ozi-spec~=0.5.2 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`5131c61`](https://github.com/OZI-Project/OZI/commit/5131c615bae759d04ba4e47df4f78cbff6d77711))

## 1.16.11 (2024-07-14)

## 1.16.10 (2024-07-13)


### ⬆️ Upgraded Dependencies

*  OZI-Project/publish@0.1.8 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`d5d8a98`](https://github.com/OZI-Project/OZI/commit/d5d8a983d9ef851db8f176d9451bc7828d5e0b47))

*  OZI-Project/release@0.6.1 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`7f62e6f`](https://github.com/OZI-Project/OZI/commit/7f62e6ff6dbf99abc471365495b357cd994db500))

*  OZI-Project/draft@0.3.5 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`92fb8fc`](https://github.com/OZI-Project/OZI/commit/92fb8fc0d3e72d0a86e91bcdadb323c6cce7f017))

*  OZI-Project/checkpoint@0.4.3 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`ac01f1f`](https://github.com/OZI-Project/OZI/commit/ac01f1f9b24e2bcdc3a32b1978447e95426b980c))


### 🐛 Fixed Bugs

*  fix changelog heading levels.
([`6e55aa2`](https://github.com/OZI-Project/OZI/commit/6e55aa2814c3d23847c478ba46fb10e357eadf67))


### 🚸 Improved Usability

* (CHANGELOG.md): lower release heading levels — rjdbcm &lt;ozi.project@outlook.com&gt;
([`b7427a0`](https://github.com/OZI-Project/OZI/commit/b7427a0d1c56d7277af375380f293b342bd5b8cc))

## 1.16.9 (2024-07-12)


### ⬆️ Upgraded Dependencies

*  Bump actions/dependency-review-action from 4.3.3 to 4.3.4

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.3.3 to 4.3.4.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/72eb03d02c7872a771aacd928f3123ac62ad6d3a...5a2ce3f5b92ee19cbb1541a4984c76d921601d7c)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`b54dce2`](https://github.com/OZI-Project/OZI/commit/b54dce2123a706773b36200c59f70cfa6c3aae65))

*  Bump github/codeql-action from 3.25.11 to 3.25.12

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.11 to 3.25.12.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/b611370bb5703a7efb587f9d136a52ea24c5c38c...4fa2a7953630fd2f3fb380f21be14ede0169dd4f)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`75ee5b9`](https://github.com/OZI-Project/OZI/commit/75ee5b9d8a88d2213de4c280120bdece607efddc))


### 🐛 Fixed Bugs

* (ozi-new): remove pipe guard from args — rjdbcm &lt;ozi.project@outlook.com&gt;
([`53bf713`](https://github.com/OZI-Project/OZI/commit/53bf713ce010eaeae418606e0bf652778cb7a591))

## 1.16.8 (2024-07-12)

## 1.16.7 (2024-07-12)

## 1.16.6 (2024-07-12)

## 1.16.5 (2024-07-11)

## 1.16.4 (2024-07-11)

## 1.16.3 (2024-07-11)

## 1.16.2 (2024-07-11)


### ⬆️ Upgraded Dependencies

* 🐛 ozi-core&gt;=0.0.2, fix cli arg order — rjdbcm &lt;ozi.project@outlook.com&gt;
([`641811a`](https://github.com/OZI-Project/OZI/commit/641811a9c4368599b02a7b9b5c7a996a2d64d0d7))


### 🐛 Fixed Bugs

*  fix missing version arg to ``ozi_spec.actions.info()`` — rjdbcm &lt;ozi.project@outlook.com&gt;
([`a1b586c`](https://github.com/OZI-Project/OZI/commit/a1b586c32f0e7b590ff5152fde736f65434617c1))

*  fix missing check_version arg
([`dc5dc41`](https://github.com/OZI-Project/OZI/commit/dc5dc419ccda6b2a4383846154bce311eae3a8a4))

*  fix metadata output, version, and check version — rjdbcm &lt;ozi.project@outlook.com&gt;
([`8836652`](https://github.com/OZI-Project/OZI/commit/883665288cce4e48e9c8f2031f35429a1a0e0d5b))


### 📌 Pinned Dependencies

*  ozi-core~=0.1.4 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`ae758b0`](https://github.com/OZI-Project/OZI/commit/ae758b033b4b70afa0ea72d313b3c390e7e9cc0d))

*  ozi-core~=0.1.3 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`0dc05f7`](https://github.com/OZI-Project/OZI/commit/0dc05f75763b3761ec501270d5fe62002bd1be3a))

*  ozi-core~=0.1.2
([`b31b97f`](https://github.com/OZI-Project/OZI/commit/b31b97f95d4281d061b462cde6aae45d952fe897))

*  ozi-core~=0.1.1 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`e03473c`](https://github.com/OZI-Project/OZI/commit/e03473ce8c8b371e3876669be1612b13719e06af))

## 1.16.1 (2024-07-11)

## 1.16.0 (2024-07-10)


### ✨ Implemented Features

*  smaller CI footprint with the ``ozi-core`` package

Release/1.15
([`535dfe8`](https://github.com/OZI-Project/OZI/commit/535dfe8f1f269cba37acfbd3ce01886adccc5564))

## 1.15.3 (2024-07-10)


### 🚸 Improved Usability

*  extract core functions to ``ozi-core`` package — rjdbcm &lt;ozi.project@outlook.com&gt;
([`9b02455`](https://github.com/OZI-Project/OZI/commit/9b02455a0924e84dc44a2b6982dbccc7a9d06a1c))


### 🔥 Deleted Code or Files

*  remove alternate ``ozi-fix`` and ``ozi-new`` entrypoints throught ``ozi`` — rjdbcm &lt;ozi.project@outlook.com&gt;
([`096406f`](https://github.com/OZI-Project/OZI/commit/096406faedcf9fc66b36db60d74b010c9ea96505))


### 🏷️


* (pyright): ignore ozi-core for now — rjdbcm &lt;ozi.project@outlook.com&gt;
([`f900b16`](https://github.com/OZI-Project/OZI/commit/f900b1683953c7d9ae9e5facc95b2339d6b21d6a))

* (mypy): add overrides for ``ozi-core`` — rjdbcm &lt;ozi.project@outlook.com&gt;
([`d362cfb`](https://github.com/OZI-Project/OZI/commit/d362cfbcab8268043d6147865bc9081f0595cfa4))


### 📌 Pinned Dependencies

*  ozi-core&gt;=0.0.1 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`8fb43cb`](https://github.com/OZI-Project/OZI/commit/8fb43cb275a794035c1cb4b15afbd7a5207eadf2))


### Other


* 🚨: run isort — rjdbcm &lt;ozi.project@outlook.com&gt;
([`39cca58`](https://github.com/OZI-Project/OZI/commit/39cca5823ba9d283fa380c76b0ad29cfaefa14c1))

* Update FUNDING.yml — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`b976520`](https://github.com/OZI-Project/OZI/commit/b976520f9368e786ed1ad0e7384ea36289c42852))

## 1.15.2 (2024-07-10)


### 🚸 Improved Usability

* (ozi.new): move ``pre/postprocess_arguments`` to ``ozi.new.validate`` — rjdbcm &lt;ozi.project@outlook.com&gt;
([`4bb70e2`](https://github.com/OZI-Project/OZI/commit/4bb70e29ffeb9ecdbf667a0540bd61f274fc7d42))


### 🔨 Updated Scripts

*  remove ``semantic_release`` from dist suite — rjdbcm &lt;ozi.project@outlook.com&gt;
([`047ac59`](https://github.com/OZI-Project/OZI/commit/047ac59418f7b441e2124fdf16aa2c05b0f8dbdd))


### Other


* 🚨(ozi.render): run black — rjdbcm &lt;ozi.project@outlook.com&gt;
([`964e9c5`](https://github.com/OZI-Project/OZI/commit/964e9c5f205f725aa08136ba8db6ec3ee15774ee))

* 🚨(ozi.render): version guard for Self type — rjdbcm &lt;ozi.project@outlook.com&gt;
([`863e32b`](https://github.com/OZI-Project/OZI/commit/863e32b9417772f7e8a22c6d78c9d26c0350fc8a))

## 1.15.1 (2024-07-08)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/publish from 0.1.6 to 0.1.7

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.6 to 0.1.7.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/5f82de29a76b1befa60a5b99752a881a83aeed47...1d1a105c970d1600a544bf67b93ef09fefe722cf)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`e88bde8`](https://github.com/OZI-Project/OZI/commit/e88bde8872a6f0aae6f139788eb568d09ddf745d))

*  Bump actions/upload-artifact from 4.3.3 to 4.3.4

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.3.3 to 4.3.4.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/65462800fd760344b1a7b4382951275a0abb4808...0b2256b8c012f0828dc542b3febcab082c67f72b)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`040cbc3`](https://github.com/OZI-Project/OZI/commit/040cbc3e46bd5511209fe5f2ae7cd08473ade94d))

*  Bump OZI-Project/draft from 0.3.3 to 0.3.4

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.3 to 0.3.4.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/1662727a1f63e3344fc5bda22ff785083596c8c3...58ae20c3cd6b2754a602bb4315bc80eee6c9d495)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`ab93b00`](https://github.com/OZI-Project/OZI/commit/ab93b00d004f4f31f6bde21fd8fc5289ca4c5cdb))

## 1.15.0 (2024-07-08)


### Other


* Update meson.options - semantic_release removed from should_fail — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`bbbf973`](https://github.com/OZI-Project/OZI/commit/bbbf973889cf08f15164858b333bdd590005b874))

## 1.14.10 (2024-07-06)


### 🐛 Fixed Bugs

*  add ``except configparser.NoSectionError`` to ci user lookup — rjdbcm &lt;ozi.project@outlook.com&gt;
([`4c819fb`](https://github.com/OZI-Project/OZI/commit/4c819fbb8d25058725c23d8e4414c93c6695a006))

* (ozi-fix missing): warn on missing required directories — rjdbcm &lt;ozi.project@outlook.com&gt;
([`8486918`](https://github.com/OZI-Project/OZI/commit/84869185690798aee9412925c595e7b6ced59643))


### 🚸 Improved Usability

* (ozi.render): add RenderedContent class — rjdbcm &lt;ozi.project@outlook.com&gt;
([`707d9bc`](https://github.com/OZI-Project/OZI/commit/707d9bc89d6dd8391f90027786bb9b29365c3bb8))

* (ozi.spdx): add user-defined license expression to parser — rjdbcm &lt;ozi.project@outlook.com&gt;
([`cd0fca7`](https://github.com/OZI-Project/OZI/commit/cd0fca7c8c520ad829a6f7dc8124efd4bfe92b6a))

* (ozi.render): git init a repo for new projects — rjdbcm &lt;ozi.project@outlook.com&gt;
([`17acd16`](https://github.com/OZI-Project/OZI/commit/17acd16c9349b1c1669f5960ece2c3af0f7d1a97))


### 📌 Pinned Dependencies

*  trove-classifiers~=2024.7 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`51e4228`](https://github.com/OZI-Project/OZI/commit/51e42281566f60d09977fa5690eb7c51a4837bf7))

*  TAP-Producer~=0.1.1 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`3b85987`](https://github.com/OZI-Project/OZI/commit/3b85987eb71c18ab33a441d302c9d0285cfbe523))


### ✨ Implemented Features

* 📌 ozi-spec~=0.5; ozi-templates~=2.5.1 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`6a22639`](https://github.com/OZI-Project/OZI/commit/6a22639e76d0b2a21fa65a5791ac2adbda673e4d))


### 🔨 Updated Configuration

* (meson.options): add &#39;semantic_release&#39; to ``should_fail`` — rjdbcm &lt;ozi.project@outlook.com&gt;
([`797d211`](https://github.com/OZI-Project/OZI/commit/797d211daba1e330758bbf688afa4fb7481d8d46))


### Other


* 🚨 hide some noqa from ruff — rjdbcm &lt;ozi.project@outlook.com&gt;
([`15f07a1`](https://github.com/OZI-Project/OZI/commit/15f07a1f791a16c707225d121df487c2543e635e))

* 🚨 no cover missing required directory — rjdbcm &lt;ozi.project@outlook.com&gt;
([`12d8298`](https://github.com/OZI-Project/OZI/commit/12d8298ed9804eb0fe4fdb5a731ac647b0bbfed2))

## 1.14.9 (2024-07-04)

## 1.14.8 (2024-07-04)


### 🐛 Fixed Bugs

*  use lowercase name in ``ozi.fix.missing:required_files`` — rjdbcm &lt;ozi.project@outlook.com&gt;
([`795cd4d`](https://github.com/OZI-Project/OZI/commit/795cd4de1f7da26cde29d2768a3bb76fff6fbfa8))


### 🚸 Improved Usability

*  move ``ozi.tap`` to ``TAP-Producer`` package — rjdbcm &lt;ozi.project@outlook.com&gt;
([`e5b317e`](https://github.com/OZI-Project/OZI/commit/e5b317e61f2862f8e44d4d8679d5e6a9f9ac3aae))


### ✏️ Corrected Typos

* 📝 CHANGELOG.md.j2 add project name to heading — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`547bc75`](https://github.com/OZI-Project/OZI/commit/547bc75ac6636842f5592b1310643d113c354872))

## 1.14.7 (2024-07-03)

## 1.14.6 (2024-07-03)


### 🐛 Fixed Bugs

*  lowercase name in ``ozi.render.render_project_files`` — rjdbcm &lt;ozi.project@outlook.com&gt;
([`a18015a`](https://github.com/OZI-Project/OZI/commit/a18015ad442ea71fc48cb2d9ffd479a63bfeddff))

*  fix name normalization — rjdbcm &lt;ozi.project@outlook.com&gt;
([`1974a37`](https://github.com/OZI-Project/OZI/commit/1974a3723550171922fceaeb77ef3817aab894c4))

* ✏️ fix changelog blank — rjdbcm &lt;ozi.project@outlook.com&gt;
([`5257621`](https://github.com/OZI-Project/OZI/commit/5257621f1b1761758721071f14bd6cd1bc9f0d25))

* ✏️ changelog displays versions *greater* than 1.0.0 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`cfeb32d`](https://github.com/OZI-Project/OZI/commit/cfeb32dee64195c477e56ed204da4388a93fbac0))


### 📌 Pinned Dependencies

*  ozi-templates~=2.4.8 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`1709f7b`](https://github.com/OZI-Project/OZI/commit/1709f7b4f676805de63945b2b9e192add815f360))

## 1.14.5 (2024-07-03)


### 🚸 Improved Usability

*  hide pre-1.0.0 commits from CHANGELOG — rjdbcm &lt;ozi.project@outlook.com&gt;
([`736bfbe`](https://github.com/OZI-Project/OZI/commit/736bfbef1efbfe8f17ce73e5d6ffe17120fc9450))


### Other


* use split method not filter — rjdbcm &lt;ozi.project@outlook.com&gt;
([`055dbfb`](https://github.com/OZI-Project/OZI/commit/055dbfb181f120610acba01fee18957fc873781d))

## 1.14.4 (2024-07-03)


### 🐛 Fixed Bugs

*  CHANGELOG duplicated commit headings fixed — rjdbcm &lt;ozi.project@outlook.com&gt;
([`0025cd6`](https://github.com/OZI-Project/OZI/commit/0025cd62fe1015e4517118eff3abbf7cae2beac4))

## 1.14.3 (2024-07-03)


### 🐛 Fixed Bugs

*  fix requirements.in render to properly ignore newlines — rjdbcm &lt;ozi.project@outlook.com&gt;
([`b313ede`](https://github.com/OZI-Project/OZI/commit/b313ede703d624962a309792973aead19e797203))

*  fix template emoji rendering — rjdbcm &lt;ozi.project@outlook.com&gt;
([`319c6d4`](https://github.com/OZI-Project/OZI/commit/319c6d443c9a0126cb174e5e688f27b3ffddd6f7))


### 🚸 Improved Usability

*  remove CHANGELOG.md from build files — rjdbcm &lt;ozi.project@outlook.com&gt;
([`cbe0c80`](https://github.com/OZI-Project/OZI/commit/cbe0c80b1346f7295204d80e953615d8f61ff34f))

* (ozi-new): use updated changelog template
([`450794c`](https://github.com/OZI-Project/OZI/commit/450794c3281d6587621466186fd8fe2b10d33610))


### 📌 Pinned Dependencies

*  ozi-templates~=2.4.3 — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`b392f0d`](https://github.com/OZI-Project/OZI/commit/b392f0dfc9847ce7b77f7ea591e040bc874ed792))

*  ozi-templates~=2.4.5 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`5a3c774`](https://github.com/OZI-Project/OZI/commit/5a3c77433758b1a2768c234cf5ba456abc48d238))


### Other


* Update CHANGELOG.md.j2 — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`b6212a9`](https://github.com/OZI-Project/OZI/commit/b6212a9e7d3ed35b760c2086c5ec3aaa70097c3c))

## 1.14.2 (2024-07-02)

## 1.14.1 (2024-07-02)

## 1.14.0 (2024-07-02)


### 🐛 Fixed Bugs

* 📝 Update CHANGELOG.md.j2 rendering — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`57e7d2c`](https://github.com/OZI-Project/OZI/commit/57e7d2c01a35907410021eebd6bcd5bee419fc92))

* 📝 Update CHANGELOG.md.j2 to fix rendering of code-blocks — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`3a2a186`](https://github.com/OZI-Project/OZI/commit/3a2a1861a0ce224b49f303ef70d2a9b3ce27048a))

## 1.13.31 (2024-07-01)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.25.10 to 3.25.11

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.10 to 3.25.11.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/23acc5c183826b7a8a97bce3cecc52db901f8251...b611370bb5703a7efb587f9d136a52ea24c5c38c)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`1b166f0`](https://github.com/OZI-Project/OZI/commit/1b166f062bd3f8a8186512d80479460bdc37f1ce))


### 🏷️


* (mypy): ``ozi_spec.*: ignore_missing_imports = true`` — rjdbcm &lt;ozi.project@outlook.com&gt;
([`a016b31`](https://github.com/OZI-Project/OZI/commit/a016b3147258dc5a2c6ee8ea4d847f59fb2d9742))

* (mypy): ignore_errors ``ozi_spec.*`` — rjdbcm &lt;ozi.project@outlook.com&gt;
([`13f57a6`](https://github.com/OZI-Project/OZI/commit/13f57a60ed8e70efb19ca0baa85e15f55ccb495c))

*  pyright: ignore ``ozi_spec`` — rjdbcm &lt;ozi.project@outlook.com&gt;
([`0fe813c`](https://github.com/OZI-Project/OZI/commit/0fe813ceb16910cda27f05207c111e07c1d402bc))


### ✨ Implemented Features

*  move spec to ozi-spec package — rjdbcm &lt;ozi.project@outlook.com&gt;
([`80c6709`](https://github.com/OZI-Project/OZI/commit/80c6709a891e32b24e2af9df1c5a556fb4044ba7))


### Other


* 🚨 run linters — rjdbcm &lt;ozi.project@outlook.com&gt;
([`cddd84e`](https://github.com/OZI-Project/OZI/commit/cddd84ea3e3f4a7fd7bfbb606974c7deec0caa36))

## 1.13.30 (2024-06-30)

## 1.13.29 (2024-06-30)

## 1.13.28 (2024-06-30)

## 1.13.27 (2024-06-29)

## 1.13.26 (2024-06-29)


### 🐛 Fixed Bugs

*  Admonition modal min 40 columns wide instead of 8 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`0edcc3b`](https://github.com/OZI-Project/OZI/commit/0edcc3bf326041416fabf7c522d739197f91d460))

* (ozi-new interactive): fix arg passing to ``ozi-new project`` — rjdbcm &lt;ozi.project@outlook.com&gt;
([`561d068`](https://github.com/OZI-Project/OZI/commit/561d068913efa0f8b5a3eb4f53cab956ab55dcd6))

* (ozi-new interactive): fix arg passing using chain — rjdbcm &lt;ozi.project@outlook.com&gt;
([`3afe7ba`](https://github.com/OZI-Project/OZI/commit/3afe7ba1511160086e4efa6b77d080dd00e5b1c8))

* (ozi-fix interactive): fix KeyError when editing classifiers — rjdbcm &lt;ozi.project@outlook.com&gt;
([`c6fb751`](https://github.com/OZI-Project/OZI/commit/c6fb7517abd9a5cb824007217442eb299c133552))

* (ozi-fix interactive): fix argument outputs — rjdbcm &lt;ozi.project@outlook.com&gt;
([`2bfd894`](https://github.com/OZI-Project/OZI/commit/2bfd894304b874ad7dbb1708e2aedd4e1efce414))


### 📌 Pinned Dependencies

* ozi-templates~=2.4.0

See https://github.com/OZI-Project/ozi-templates/releases/tag/2.4.0 for more info. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`8682fe5`](https://github.com/OZI-Project/OZI/commit/8682fe5e061eee359f004b0d25d934792c4cdcb0))

*  ozi-templates~=2.3.4

fixes missing ``OSI Approved :: ... Unlicense ... `` folder missing. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`dc9186c`](https://github.com/OZI-Project/OZI/commit/dc9186c210ec9b53fad9706adc85ed0368ee0fd9))

* ozi-templates~=2.3.3 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`daac072`](https://github.com/OZI-Project/OZI/commit/daac0728f33eae31ab72d2abd0d177083a96a329))

## 1.13.25 (2024-06-29)

## 1.13.24 (2024-06-29)

## 1.13.23 (2024-06-29)

## 1.13.22 (2024-06-29)

## 1.13.21 (2024-06-28)

## 1.13.20 (2024-06-28)

## 1.13.19 (2024-06-28)

## 1.13.18 (2024-06-28)

## 1.13.17 (2024-06-27)

## 1.13.16 (2024-06-27)


### 🐛 Fixed Bugs

* 🏷️(ozi-new interactive) fix overlapping default conditional — rjdbcm &lt;ozi.project@outlook.com&gt;
([`97272e3`](https://github.com/OZI-Project/OZI/commit/97272e3fa241dd76d92f17fe0340e9b7c88d3761))

* (ozi-new interactive): fix option arg setting — rjdbcm &lt;ozi.project@outlook.com&gt;
([`758c91d`](https://github.com/OZI-Project/OZI/commit/758c91ddb39b81152e907b878229b48748a25d07))

* (ozi-new interactive): use mapping for setting args — rjdbcm &lt;ozi.project@outlook.com&gt;
([`38530a8`](https://github.com/OZI-Project/OZI/commit/38530a821565dd17722708cdf9a8188964c11756))

*  correct zlib to Zlib — rjdbcm &lt;ozi.project@outlook.com&gt;
([`76f3818`](https://github.com/OZI-Project/OZI/commit/76f3818af8e56cf91d4223942a63cd5f022cd6e8))

* ✏️: correct license short ids — rjdbcm &lt;ozi.project@outlook.com&gt;
([`8148c7b`](https://github.com/OZI-Project/OZI/commit/8148c7b88b1e3c26f992393632dbaca8dc227c1b))

* (ozi-new interactive): args output fixed and project_urls added — rjdbcm &lt;ozi.project@outlook.com&gt;
([`fcfcdba`](https://github.com/OZI-Project/OZI/commit/fcfcdbab57632f9b928f82001ab528f84bfd7438))

* ✏️ fix EUPL license IDs — rjdbcm &lt;ozi.project@outlook.com&gt;
([`b0a9425`](https://github.com/OZI-Project/OZI/commit/b0a94256692e919a80da97265875ec3e31883b83))

*  fix missing License :: Eiffel Forum License (EFL) — rjdbcm &lt;ozi.project@outlook.com&gt;
([`d263034`](https://github.com/OZI-Project/OZI/commit/d2630342b2257add6fbb2cd8e958d9d13e4db90f))

* (ozi-new interactive): fix missing license suggestions — rjdbcm &lt;ozi.project@outlook.com&gt;
([`21e0a4a`](https://github.com/OZI-Project/OZI/commit/21e0a4af19315fb19492c4e057aba2a8e6381229))

*  missing licenses and unsupported licenses list added — rjdbcm &lt;ozi.project@outlook.com&gt;
([`ac65c05`](https://github.com/OZI-Project/OZI/commit/ac65c059bdcb378c1d649eaf7590ad2d450e7b1a))

*  fix list indexing in license_expression — rjdbcm &lt;ozi.project@outlook.com&gt;
([`c47cad8`](https://github.com/OZI-Project/OZI/commit/c47cad82b89c488ca4011753c7b1ea6cc36e57ae))

*  fix license expression dialog crash — rjdbcm &lt;ozi.project@outlook.com&gt;
([`4babcd3`](https://github.com/OZI-Project/OZI/commit/4babcd3a5a644c6f7b58bb11d07ae1d76997f519))

* (ozi-new interactive): fix list argument rendering — rjdbcm &lt;ozi.project@outlook.com&gt;
([`0becd2e`](https://github.com/OZI-Project/OZI/commit/0becd2e29621c486f66cde130fc85d5b4399a846))

* (ozi-new interactive): fix arg quoting — rjdbcm &lt;ozi.project@outlook.com&gt;
([`0b8d0fd`](https://github.com/OZI-Project/OZI/commit/0b8d0fd1e2e22366cafc31f4efc5c07b71063685))

* (ozi-new interactive): hide cursor and wrap lines in Admonitions — rjdbcm &lt;ozi.project@outlook.com&gt;
([`d1cf3da`](https://github.com/OZI-Project/OZI/commit/d1cf3da8c80b577f38748be221017f7ddf65b082))

* (ozi-new interactive): correct handling of list args
([`862460d`](https://github.com/OZI-Project/OZI/commit/862460d9aacdde8c9e8169074d048ca338d28754))

* (ozi-new): accept standard Requires-Dist argument form
([`fc0401e`](https://github.com/OZI-Project/OZI/commit/fc0401ef9129663ae62e0da9b8d5b32b6a584340))


### 🏷️


* ``SPDX_LICENSE_MAP: dict[str, Sequence[str]]`` — rjdbcm &lt;ozi.project@outlook.com&gt;
([`22a5ed5`](https://github.com/OZI-Project/OZI/commit/22a5ed54d6669433bce1dab02625aa0021a3b839))

* (ozi-new interactive): fix license_expression dialog typing — rjdbcm &lt;ozi.project@outlook.com&gt;
([`399d270`](https://github.com/OZI-Project/OZI/commit/399d270521355a035128d944c2ceed4e2733f5ba))


### 📌 Pinned Dependencies

*  ozi-templates~=2.3.2 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`97f1f90`](https://github.com/OZI-Project/OZI/commit/97f1f9099336394381787e9290a9cfa8c661faa5))

*  ozi-templates~=2.3.1 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`d88b026`](https://github.com/OZI-Project/OZI/commit/d88b026a8c54b0d4f8d6850da5a355b7c6250370))

* ozi-templates~=2.3.0 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`f7bbaa5`](https://github.com/OZI-Project/OZI/commit/f7bbaa59cacf87afca6a265629c00e41f15485df))


### Other


* 🚨(ozi-new interactive): run lint — rjdbcm &lt;ozi.project@outlook.com&gt;
([`c334f68`](https://github.com/OZI-Project/OZI/commit/c334f6873e3c1c7c787b3ac7e33d01a453d044c6))

## 1.13.15 (2024-06-26)

## 1.13.14 (2024-06-24)

## 1.13.13 (2024-06-24)


### 🐛 Fixed Bugs

* (ozi-new interactive): refactor and fix prompts — rjdbcm &lt;ozi.project@outlook.com&gt;
([`41f931c`](https://github.com/OZI-Project/OZI/commit/41f931cddca281928deaf2b7a7c1d97694391782))


### 🔨 Updated Scripts

* (ozi-new interactive): finalize implementation — rjdbcm &lt;ozi.project@outlook.com&gt;
([`95b4aeb`](https://github.com/OZI-Project/OZI/commit/95b4aebdfca4234912691778b3eafb525b6965eb))

## 1.13.12 (2024-06-24)

## 1.13.11 (2024-06-24)

## 1.13.10 (2024-06-23)

## 1.13.9 (2024-06-23)


### 🐛 Fixed Bugs

* (ozi-new interactive): fix disclaimer text styling — rjdbcm &lt;ozi.project@outlook.com&gt;
([`3d8864a`](https://github.com/OZI-Project/OZI/commit/3d8864a182ae049c3a53cc2cc2bc695c128e11c6))

* 📄: updated disclaimer for CLI apps — rjdbcm &lt;ozi.project@outlook.com&gt;
([`5760da1`](https://github.com/OZI-Project/OZI/commit/5760da183f66de34a3d7c949bc1f01d98d2e7520))


### 🚸 Improved Usability

* 🔨(ozi-new interactive): added metadata viewer to the menu. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`fd9e7b0`](https://github.com/OZI-Project/OZI/commit/fd9e7b08d31fcf640c33b10cdde64b015f304652))


### 🔨 Updated Scripts

*  interactive mode refactor

Merge pull request #758 from OZI-Project/release/1.13
([`8e59d45`](https://github.com/OZI-Project/OZI/commit/8e59d457bdfdc9e7bdc1434f4885b7225fcefc6b))

* (ozi-new interactive) only scroll page on Admonition dialog — rjdbcm &lt;ozi.project@outlook.com&gt;
([`2bbbd42`](https://github.com/OZI-Project/OZI/commit/2bbbd4242d528d7e885439578d4a9bf26a82cbf7))

*  Admonition dialog class for displaying scrolling text — rjdbcm &lt;ozi.project@outlook.com&gt;
([`02dff10`](https://github.com/OZI-Project/OZI/commit/02dff10c3f87b3c279bc242469d82d0958a9be21))


### Other


* 📝(ozi-new interactive): fix usage for docs — rjdbcm &lt;ozi.project@outlook.com&gt;
([`a6bca88`](https://github.com/OZI-Project/OZI/commit/a6bca88f84574ce745d776906c06cbcd92556129))

* 🚨 run lint — rjdbcm &lt;ozi.project@outlook.com&gt;
([`771d1bd`](https://github.com/OZI-Project/OZI/commit/771d1bdeb8b4b682eafa11e3a5d6ff9da6dda2be))

* 📝 Update README — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`3ad41ee`](https://github.com/OZI-Project/OZI/commit/3ad41ee48630e301043b62c9ae683719d0ad3669))

## 1.13.8 (2024-06-23)


### 🔨 Updated Scripts

* (ozi-new interactive): refactor — rjdbcm &lt;ozi.project@outlook.com&gt;
([`d41a8b6`](https://github.com/OZI-Project/OZI/commit/d41a8b6598ca57b0633455cffa909b58186ddf0c))


### Other


* 📄 add disclaimer to prompt session start — rjdbcm &lt;ozi.project@outlook.com&gt;
([`74a34b2`](https://github.com/OZI-Project/OZI/commit/74a34b214df1cf09b054492f57c6a65b593e123f))

* 🚨 run black — rjdbcm &lt;ozi.project@outlook.com&gt;
([`00d017f`](https://github.com/OZI-Project/OZI/commit/00d017fa010a03c1bdead6e2e64bc27dbffd525c))

## 1.13.7 (2024-06-23)

## 1.13.6 (2024-06-22)

## 1.13.5 (2024-06-21)

## 1.13.4 (2024-06-21)

## 1.13.3 (2024-06-21)


### 🐛 Fixed Bugs

* 🚸(ozi-new interactive) fix styling of checkbox and radio — rjdbcm &lt;ozi.project@outlook.com&gt;
([`5a2c657`](https://github.com/OZI-Project/OZI/commit/5a2c65744bb82d2ef0a47f49600d5dd1bb52ba14))

* (interactive prompt): add summary validator — rjdbcm &lt;ozi.project@outlook.com&gt;
([`2d6849b`](https://github.com/OZI-Project/OZI/commit/2d6849b007a0e017adea3bdcaf28eadbd11c096f))


### 🚸 Improved Usability

*  enhanced prompt with menu — rjdbcm &lt;ozi.project@outlook.com&gt;
([`e8ac4e0`](https://github.com/OZI-Project/OZI/commit/e8ac4e0e1251bac2c186a13382e8ca7f237a6518))


### 🔨 Updated Scripts

*  add ``--check-package-exists`` bool to interactive args

refactor menu system — rjdbcm &lt;ozi.project@outlook.com&gt;
([`f79d467`](https://github.com/OZI-Project/OZI/commit/f79d467fe208d7421397c20459e25150c389e661))


### Other


* 🚨 run black — rjdbcm &lt;ozi.project@outlook.com&gt;
([`5748852`](https://github.com/OZI-Project/OZI/commit/5748852a3e842d81970b4974e2257543707964d3))

## 1.13.2 (2024-06-21)

## 1.13.1 (2024-06-21)

## 1.13.0 (2024-06-21)


### ⬆️ Upgraded Dependencies

*  ozi-templates~=2.1.2 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`0c4e9ac`](https://github.com/OZI-Project/OZI/commit/0c4e9acdf2a70a99af697a123abc5eafa21ae15c))


### 🐛 Fixed Bugs

*  fix summary arg — rjdbcm &lt;ozi.project@outlook.com&gt;
([`22bffda`](https://github.com/OZI-Project/OZI/commit/22bffda89bd6b460aab81d1ad2b15e957ef00137))

* 📝: add interactive doc help — rjdbcm &lt;ozi.project@outlook.com&gt;
([`0b4c054`](https://github.com/OZI-Project/OZI/commit/0b4c054d402a8eec06fa49d0d6aa6e194af340b3))

*  fix errant rendering of parsed_commit_heading stub — rjdbcm &lt;ozi.project@outlook.com&gt;
([`96c0306`](https://github.com/OZI-Project/OZI/commit/96c03066cfa0d56b36c5d29fb5276604d3e148d7))


### 🚸 Improved Usability

* clarify interactive prompt ``Cancel`` becomes ``Skip``
([`486f6b1`](https://github.com/OZI-Project/OZI/commit/486f6b1a0bae3107e0ac44d495dfdb4131a32a43))

* (interactive prompt): add final confirm dialog — rjdbcm &lt;ozi.project@outlook.com&gt;
([`045df8a`](https://github.com/OZI-Project/OZI/commit/045df8a1f428fd9a9668ebfb7d5d87755a90f111))


### Other


* 📝 add versionadded to docstring — rjdbcm &lt;ozi.project@outlook.com&gt;
([`5428424`](https://github.com/OZI-Project/OZI/commit/54284248e8b3cd3d70bab76e0386008669d42a1a))

## 1.12.8 (2024-06-20)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/draft from 0.3.2 to 0.3.3

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.2 to 0.3.3.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/4cb9feb842df0dcd1e48c0f64f3b61e0ac64f05d...1662727a1f63e3344fc5bda22ff785083596c8c3)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`1af206c`](https://github.com/OZI-Project/OZI/commit/1af206c9815d97b0a3d808c14051b30b47efbf10))

*  Bump OZI-Project/publish from 0.1.5 to 0.1.6

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.5 to 0.1.6.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/edb7e48d4196153b8dabddb970405495e1ff2092...5f82de29a76b1befa60a5b99752a881a83aeed47)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`5938b98`](https://github.com/OZI-Project/OZI/commit/5938b98e43f5aef127cb0bd0a34e77ab54ec514e))

*  ozi-templates~=2.1.1 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`af47885`](https://github.com/OZI-Project/OZI/commit/af478850a43ea3d10fd97845d05648b02d60a33b))


### 🐛 Fixed Bugs

* (ozi.scripts.render_requirements): correct filtering of empty lines — rjdbcm &lt;ozi.project@outlook.com&gt;
([`e9f671a`](https://github.com/OZI-Project/OZI/commit/e9f671a89485ebfec1f2d47786319067918c9f81))

*  remove mkdir templates in test — rjdbcm &lt;ozi.project@outlook.com&gt;
([`cc02853`](https://github.com/OZI-Project/OZI/commit/cc028537fe31d6bec848bc8135b4227856ae1801))

*  use pathlib idiom for template rendering — rjdbcm &lt;ozi.project@outlook.com&gt;
([`89ff2d6`](https://github.com/OZI-Project/OZI/commit/89ff2d635ab03317848e71374d92b9edbf7ede27))

*  add previously deleted ``blastpipe.wrap`` — rjdbcm &lt;ozi.project@outlook.com&gt;
([`aa7f8f7`](https://github.com/OZI-Project/OZI/commit/aa7f8f7681a7839db7cd6c29fc26c883a78e3768))


### ➕ Added Dependencies

*  add ``prompt_toolkit`` as a dependency — rjdbcm &lt;ozi.project@outlook.com&gt;
([`7e46ff6`](https://github.com/OZI-Project/OZI/commit/7e46ff680fce8fe619d0916a774b6e9ec878dcbe))


### ✏️ Corrected Typos

*  render templates set write mode — rjdbcm &lt;ozi.project@outlook.com&gt;
([`528abd8`](https://github.com/OZI-Project/OZI/commit/528abd87e42dae88532746d31d4f959f2864ce1c))


### 📌 Pinned Dependencies

* (checkpoint,draft,release,publish): update patch version — rjdbcm &lt;ozi.project@outlook.com&gt;
([`2fa3193`](https://github.com/OZI-Project/OZI/commit/2fa3193f2e07b9f7fc31bd8cdd07914ef8e5d3cb))


### ✨ Implemented Features

* (ozi-new): add interactive prompt mode — rjdbcm &lt;ozi.project@outlook.com&gt;
([`9576024`](https://github.com/OZI-Project/OZI/commit/95760249a73bf915c9502122e3938d9b5adabc1f))

* (ozi.render): add ``render_templates`` function

Renders templates folder with CHANGELOG and release notes templates for semantic-release. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`bd1eb95`](https://github.com/OZI-Project/OZI/commit/bd1eb95fd92477001691bb765adbbcdfcf8a6005))


### Other


* 🚨 ``# noqa: ANN101`` Validator classes — rjdbcm &lt;ozi.project@outlook.com&gt;
([`7b7dff0`](https://github.com/OZI-Project/OZI/commit/7b7dff03f903916c5ced759cffb01b04853558ab))

* 🚨 lint cleanup — rjdbcm &lt;ozi.project@outlook.com&gt;
([`896af32`](https://github.com/OZI-Project/OZI/commit/896af323a37c0db963479616cbbb475963a0193a))

* 🚨 ignore type ignore — rjdbcm &lt;ozi.project@outlook.com&gt;
([`3556c91`](https://github.com/OZI-Project/OZI/commit/3556c91d50be947066048e705643d6c64fc6a98d))

* 🚨 move Self to typechecking guard — rjdbcm &lt;ozi.project@outlook.com&gt;
([`4a1dfd4`](https://github.com/OZI-Project/OZI/commit/4a1dfd4f68e78bdb725e7faafce255a129c9bbb6))

* 🚨 clean up lint — rjdbcm &lt;ozi.project@outlook.com&gt;
([`6fe1102`](https://github.com/OZI-Project/OZI/commit/6fe110290861a920a25249e1bd0040d8816a27d7))

* 📝 update docstrings — rjdbcm &lt;ozi.project@outlook.com&gt;
([`2a33b0b`](https://github.com/OZI-Project/OZI/commit/2a33b0b6421e410947f8b8980820d76658d14b1e))

* 📝 fix changelog template — rjdbcm &lt;ozi.project@outlook.com&gt;
([`c42f603`](https://github.com/OZI-Project/OZI/commit/c42f60312bc93debea3f2ddf28cea5b4e66cbb7e))

## 1.12.7 (2024-06-19)

## 1.12.6 (2024-06-19)

## 1.12.5 (2024-06-18)

## 1.12.4 (2024-06-18)

## 1.12.3 (2024-06-17)


### 🐛 Fixed Bugs

*  fix argv missing in ``ozi-new`` output — rjdbcm &lt;ozi.project@outlook.com&gt;
([`92899a7`](https://github.com/OZI-Project/OZI/commit/92899a7c588d5984393fa6964529bde80be99b29))


### 🚸 Improved Usability

* ``ozi-new`` now accepts stdin — rjdbcm &lt;ozi.project@outlook.com&gt;
([`05da91e`](https://github.com/OZI-Project/OZI/commit/05da91e7fe932ff292f2562632016dec24f2f821))

*  ``PKG-INFO required`` arguments to ``ozi-new`` no longer required — rjdbcm &lt;ozi.project@outlook.com&gt;
([`0a20811`](https://github.com/OZI-Project/OZI/commit/0a20811c34574c7055b126824d97fadaea2c6093))


### ✏️ Corrected Typos

*  Better changelog — rjdbcm &lt;ozi.project@outlook.com&gt;
([`6f3f525`](https://github.com/OZI-Project/OZI/commit/6f3f525ce4d677b0310e140ab6b2fb804c518125))


### 📌 Pinned Dependencies

* (requirements.in): ozi-templates&gt;=2.0.5

(checkpoint.yml.j2): prerelease checkpoint no longer included — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`bb9ff99`](https://github.com/OZI-Project/OZI/commit/bb9ff9904bde50fc3a08adb5ad447d7940ba0108))


### 🔨 Updated Configuration

*  re-enable blastpipe bootstrap — rjdbcm &lt;ozi.project@outlook.com&gt;
([`3c062d6`](https://github.com/OZI-Project/OZI/commit/3c062d664a150bb4823f9ff735c47ec2bab5547b))


### Other


* 📝: remove horizontal dividers from CHANGELOG template — rjdbcm &lt;ozi.project@outlook.com&gt;
([`ee50072`](https://github.com/OZI-Project/OZI/commit/ee5007224f8778f802de2a324f4b756ab7850357))

* 📝 clean up release_notes and CHANGELOG templates — rjdbcm &lt;ozi.project@outlook.com&gt;
([`2b9eaaf`](https://github.com/OZI-Project/OZI/commit/2b9eaaf64fd99323f87079b0e475dc2fc7f0b06e))

* 🚨 run black — rjdbcm &lt;ozi.project@outlook.com&gt;
([`64ddc38`](https://github.com/OZI-Project/OZI/commit/64ddc381d4f18fae96e114f33c55d04a283c0ffa))

## 1.12.2 (2024-06-17)


### 🐛 Fixed Bugs

* 📝: Consistent CLI documentation. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`cc37091`](https://github.com/OZI-Project/OZI/commit/cc370919b9f0dd8f353f636851f9fc2a22fe362c))

## 1.12.1 (2024-06-17)

## 1.12.0 (2024-06-17)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/release from 0.6.4 to 0.6.5

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.6.4 to 0.6.5.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/cfe06ef22488ee71ba4f2807b16bbdba1a6fb26f...f99b4e470f3dc50884d227dff38c18c3f0f3f927)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`48dff8c`](https://github.com/OZI-Project/OZI/commit/48dff8c46bb12abda13e7334bff7cae9dd894c91))


### 🐛 Fixed Bugs

* 📝: fix documentation refs — rjdbcm &lt;ozi.project@outlook.com&gt;
([`284e8ab`](https://github.com/OZI-Project/OZI/commit/284e8abde89e39a65fc1674ef0a13780be41435d))

## 1.11.12 (2024-06-16)


### 📌 Pinned Dependencies

*  ozi-templates&gt;=2.0.4 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`8d5e3ba`](https://github.com/OZI-Project/OZI/commit/8d5e3ba5832de8008040e1426abfbdcd114914de))


### ✨ Implemented Features

*  ozi-templates becomes a dependency

No longer depends on blastpipe. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`dc6882e`](https://github.com/OZI-Project/OZI/commit/dc6882e32ae96f7aa835a41194978a469f245402))

*  ozi-templates becomes a dependency

No longer depends on blastpipe. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`8d17090`](https://github.com/OZI-Project/OZI/commit/8d170905e2edc16989c4fc1858884a70ff84ba7b))


### Other


* bump ozi-templates — rjdbcm &lt;ozi.project@outlook.com&gt;
([`3bec2f5`](https://github.com/OZI-Project/OZI/commit/3bec2f5e9644ec01737d7a1d3a125a1ec81d209e))

* 🚨 fix lint — rjdbcm &lt;ozi.project@outlook.com&gt;
([`427e3ca`](https://github.com/OZI-Project/OZI/commit/427e3ca8ee25f9443654863c90833e88e77fd23e))

## 1.11.11 (2024-06-16)

## 1.11.10 (2024-06-16)

## 1.11.9 (2024-06-15)

## 1.11.8 (2024-06-14)


### ⬆️ Upgraded Dependencies

*  OZI.build&gt;=0.0.26 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`a271807`](https://github.com/OZI-Project/OZI/commit/a2718078dfda696a437c57dc0afeb073244d72e1))

*  OZI.build 0.0.25
([`fd5bb40`](https://github.com/OZI-Project/OZI/commit/fd5bb400c81a2bf588d82b3f43cd92accad5264b))

* (requirements): blastpipe 2024.11.9 — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`3f92b5f`](https://github.com/OZI-Project/OZI/commit/3f92b5fc05c534cc8a0453943f508bf0a3c5afed))

* (requirements): blastpipe 2024.11.7 — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`322c17e`](https://github.com/OZI-Project/OZI/commit/322c17ec29c220ce26e9d15b08d83c52d6bc1bd1))

*  Bump OZI-Project/draft from 0.3.1 to 0.3.2

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.1 to 0.3.2.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/f136e6eb55507553aee04e92455cc2dc279583fc...4cb9feb842df0dcd1e48c0f64f3b61e0ac64f05d)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`a63c4cb`](https://github.com/OZI-Project/OZI/commit/a63c4cbed578a379c1e272ccad886ac98b57b7a3))

*  Bump github/codeql-action from 3.25.9 to 3.25.10

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.9 to 3.25.10.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/530d4feaa9c62aaab2d250371e2061eb7a172363...23acc5c183826b7a8a97bce3cecc52db901f8251)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`62a0043`](https://github.com/OZI-Project/OZI/commit/62a0043eb2eb7b4ae222b88ac7ba76b8c0e6d6e5))

*  Bump OZI-Project/checkpoint from 0.4.1 to 0.4.2

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.4.1 to 0.4.2.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/6cc6de3235d61a5bae47fa03e773a2af9a985016...f8acf37d2479db59d191e5f6324758e224149bd0)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`77f7b33`](https://github.com/OZI-Project/OZI/commit/77f7b33f6b207faead794527c343d52ba2badf38))

*  Bump OZI-Project/checkpoint from 0.4.0 to 0.4.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.4.0 to 0.4.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.4.0...6cc6de3235d61a5bae47fa03e773a2af9a985016)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`7f1329c`](https://github.com/OZI-Project/OZI/commit/7f1329c3371455d9b23e2c42541ea787c7c0f12d))

*  Bump actions/checkout from 4.1.6 to 4.1.7

Bumps [actions/checkout](https://github.com/actions/checkout) from 4.1.6 to 4.1.7.
- [Release notes](https://github.com/actions/checkout/releases)
- [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
- [Commits](https://github.com/actions/checkout/compare/a5ac7e51b41094c92402da3b24376905380afc29...692973e3d937129bcbf40652eb9f2f61becf3332)


updated-dependencies:
- dependency-name: actions/checkout
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`509a199`](https://github.com/OZI-Project/OZI/commit/509a1992c59d5ff8f36222a59ea5201c3015598b))

*  Bump github/codeql-action from 3.25.8 to 3.25.9

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.8 to 3.25.9.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/2e230e8fe0ad3a14a340ad0815ddb96d599d2aff...530d4feaa9c62aaab2d250371e2061eb7a172363)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`94abd27`](https://github.com/OZI-Project/OZI/commit/94abd27c32507118ba9608be9dc6db46179470c3))


### 🚸 Improved Usability

*  Fix release branch patterns. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`2be2fb6`](https://github.com/OZI-Project/OZI/commit/2be2fb6d901c2042f03c7045a023c39adf3b8fa6))


### 🔨 Updated Scripts

*  revert render change — rjdbcm &lt;ozi.project@outlook.com&gt;
([`62d0c22`](https://github.com/OZI-Project/OZI/commit/62d0c22f8ecfecb0b5ccef9558df6e6a56d34975))


### 📌 Pinned Dependencies

*  blastpipe~=2024.11.10 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`556210b`](https://github.com/OZI-Project/OZI/commit/556210b18134e568dbb3d6fafbaab1e077500bc5))

## 1.11.7 (2024-06-13)

## 1.11.6 (2024-06-13)

## 1.11.5 (2024-06-12)

## 1.11.4 (2024-06-12)


### ⬆️ Upgraded Dependencies

* (requirements): blastpipe 2024.11.2 — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`1d707ec`](https://github.com/OZI-Project/OZI/commit/1d707ec21bd18263b9c11fe2f6e85f8e833e3f2d))

*  blastpipe 2024.10.5 — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`f4e6690`](https://github.com/OZI-Project/OZI/commit/f4e6690ea05cbd4bd14d2f9e7064fb7163997019))

*  Bump step-security/harden-runner from 2.8.0 to 2.8.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.8.0 to 2.8.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/f086349bfa2bd1361f7909c78558e816508cdc10...17d0e2bd7d51742c71671bd19fa12bdc9d40a3d6)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`95e6805`](https://github.com/OZI-Project/OZI/commit/95e6805a6a52f06d1b086c58ce918bf57c35d3d4))


### 🐛 Fixed Bugs

*  Merge pull request #659 from OZI-Project/main

Merge pull request #658 from OZI-Project/release/1.11
([`e826ec6`](https://github.com/OZI-Project/OZI/commit/e826ec6038b6b4bec74ea51b45c3896049bfe20e))

* (pyproject.toml): Fix branch release match pattern escape ``.`` — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`3ab600e`](https://github.com/OZI-Project/OZI/commit/3ab600e91cd044cdd595960d64193052992e7db3))

*  add a cleanup workflow to new projects. — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`5a6c442`](https://github.com/OZI-Project/OZI/commit/5a6c442dd00dfdd59bbaca024601f2e9e1b3ab6e))

* (checkpoint): ``parallel: false`` to workaround issue with CPython countedFileLock API. — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`5667a6f`](https://github.com/OZI-Project/OZI/commit/5667a6f395e835a0f1a0331ca2502c1889af391b))

* (dist-workflow.yml) Ignore copied symlinks release@0.6.4 — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`d473142`](https://github.com/OZI-Project/OZI/commit/d47314280b1bfc80e00411b6f1d67a79e7d35132))

* (dist-workflow.yml): FIX remove copy artifact step — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`df10823`](https://github.com/OZI-Project/OZI/commit/df10823a0b9baeb67eaec2c767e9c8886a831d41))

* (dist-workflow.yml): FIX artifact download — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`e5e70c6`](https://github.com/OZI-Project/OZI/commit/e5e70c649b945ff9abea28cf03983e97c15b7ccc))

* (dist-workflow.yml) FIX artifacts in release artifact — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`1526d3c`](https://github.com/OZI-Project/OZI/commit/1526d3cf87476977ff98810414373f76515613d4))

*  correct use of ``long_description_content_type``
([`3d614b7`](https://github.com/OZI-Project/OZI/commit/3d614b772f5d0a1b6a7f7b33bd3b5d25718fd89a))

* (ozi-new): create an appropriate symlink for GitHub README rendering to work — rjdbcm &lt;ozi.project@outlook.com&gt;
([`44d2033`](https://github.com/OZI-Project/OZI/commit/44d2033ea1b6d23a1690255ee833f63a7aede975))

*  set README linguist-language — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`973b7a9`](https://github.com/OZI-Project/OZI/commit/973b7a9537bcef0f1a29925327ca773a297d4420))

*  add readme symlink for gh renderer — rjdbcm &lt;ozi.project@outlook.com&gt;
([`ae4a2f3`](https://github.com/OZI-Project/OZI/commit/ae4a2f33795da7998a10cfa585095b4d8e209eec))


### 🔨 Updated Scripts

* (render.py): minor refactor for complexity — rjdbcm &lt;ozi.project@outlook.com&gt;
([`884071c`](https://github.com/OZI-Project/OZI/commit/884071cf3877fbc62f0e6bd42f85ebbe4b11a67d))

* (cleanup.yml) permissions: read-all — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`a067dde`](https://github.com/OZI-Project/OZI/commit/a067ddea6d8b80ba2d173f9f8f3c2947148190a2))

* (cleanup.yml): permissions for cache delete — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`de29e57`](https://github.com/OZI-Project/OZI/commit/de29e572c3cff7f0676532d5721529cddc8c7861))

* (cleanup.yml): write permissions for cache delete — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`7d90049`](https://github.com/OZI-Project/OZI/commit/7d90049a552490a4cec60998b4251e3a883a6d49))

* (cleanup.yml): add toplevel permissions. — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`b89487a`](https://github.com/OZI-Project/OZI/commit/b89487ab79e1a34bc17cbe869e20b1424cfab59e))

* (cleanup.yml): ``permissions: id-token: write`` — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`042514d`](https://github.com/OZI-Project/OZI/commit/042514de337386bc646971da514fb291551e61cb))

*  harden cleanup workflow. — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`43289d6`](https://github.com/OZI-Project/OZI/commit/43289d637d7fcf44b0dc708f85e012fd94877685))

* (readme-renderer): fs.copyfile README with extension
([`f3a208c`](https://github.com/OZI-Project/OZI/commit/f3a208c57bbb57c050c3ba458bd69453c11d24f5))


### 📌 Pinned Dependencies

*  OZI-Project/release@0.6.4 — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`fef34b8`](https://github.com/OZI-Project/OZI/commit/fef34b85654da4d66d4caec5988f9347356689ad))

*  OZI-Project/release@0.6.3 — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`64f61f2`](https://github.com/OZI-Project/OZI/commit/64f61f24078cc087d4067c6d0d8c1d2e95493a29))

*  OZI-Project/release@0.6.2 — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`9aa4e68`](https://github.com/OZI-Project/OZI/commit/9aa4e684116bd1dc970fae58c80b7cc7d67a8a6e))


### 🗑️ Deprecated Code

*  delete .gitattributes and modelines — rjdbcm &lt;ozi.project@outlook.com&gt;
([`38e6785`](https://github.com/OZI-Project/OZI/commit/38e6785d3c27050907dd6e340f1c7779e6100ede))


### 🔨 Updated Configuration

* (args-readme-renderer) target README — rjdbcm &lt;ozi.project@outlook.com&gt;
([`f09c7b8`](https://github.com/OZI-Project/OZI/commit/f09c7b864abc61a0dd0b18e7119b340cdbad9c38))

* (.gitattributes): remove README from linguist-documentation — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`b3465e7`](https://github.com/OZI-Project/OZI/commit/b3465e78bede56fc869cecf05b83eb1efd7cf3f9))


### Other


* 📝 Update README — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`fb697e4`](https://github.com/OZI-Project/OZI/commit/fb697e408247a7a64936805633325a5d6aef5435))

* escape dots — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`022354d`](https://github.com/OZI-Project/OZI/commit/022354d002ca8b94e21832c41958c0d517f3e517))

* ⬆️(requirements): blastpipe 2024.11.4 — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`961b3a7`](https://github.com/OZI-Project/OZI/commit/961b3a7be9b28045c84a28a5226919d04ccf871a))

* ⬆️(requirements): blastpipe 2024.11.3 — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`b3c3181`](https://github.com/OZI-Project/OZI/commit/b3c31816002dbffa663293e412d3fb55cf56cb57))

* Update requirements.in — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`b0aecc0`](https://github.com/OZI-Project/OZI/commit/b0aecc07fa1dc2cbaa3545ce555a8f3db5978dd3))

* Create cleanup.yml — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`93a9a7a`](https://github.com/OZI-Project/OZI/commit/93a9a7ab7da6fad954e744839f8f2c0b0f01214d))

* Update dev-workflow.yml checkpoint version — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`2d9308a`](https://github.com/OZI-Project/OZI/commit/2d9308a1fa8c8279d7e878d4c0099d5d85701853))

* 🚨 ``tox -e fix`` — rjdbcm &lt;ozi.project@outlook.com&gt;
([`b3275d0`](https://github.com/OZI-Project/OZI/commit/b3275d00af09bd7e9ff91b8f8fad638b3c069556))

* remove unused import — rjdbcm &lt;ozi.project@outlook.com&gt;
([`f4c3e2e`](https://github.com/OZI-Project/OZI/commit/f4c3e2ef360c75f3efc55ed05b2c2ef7acb944f5))

* 📝 rename ``README.rst`` to ``README`` per OZI spec — rjdbcm &lt;ozi.project@outlook.com&gt;
([`d6b7e34`](https://github.com/OZI-Project/OZI/commit/d6b7e3420944fbe71718fe73c7409237b68df30c))

## 1.11.3 (2024-06-10)


### 🐛 Fixed Bugs

*  ozi.spec.base.Default now public as ozi.spec.Default — rjdbcm &lt;ozi.project@outlook.com&gt;
([`8556d46`](https://github.com/OZI-Project/OZI/commit/8556d46e5760f68889f4fa6dde0d0f566d14a4ff))


### ✏️ Corrected Typos

*  Fix docstrings in spec — rjdbcm &lt;ozi.project@outlook.com&gt;
([`235b16e`](https://github.com/OZI-Project/OZI/commit/235b16eb4bfccb53ba0006b7f0515f361f220153))

## 1.11.2 (2024-06-09)


### 🐛 Fixed Bugs

*  no cover score function — rjdbcm &lt;ozi.project@outlook.com&gt;
([`906d9f8`](https://github.com/OZI-Project/OZI/commit/906d9f8b4e85a1525d96f9cec6886ce14f827079))

*  Fix typing for ozi.spec.base.Default.
([`43f840f`](https://github.com/OZI-Project/OZI/commit/43f840f19688eb98d70cbd135ab5b17c1b0998eb))

*  rename score_file to score (score_file deprecated) — rjdbcm &lt;ozi.project@outlook.com&gt;
([`756d2c1`](https://github.com/OZI-Project/OZI/commit/756d2c1b99e3b112ebf1c3f70e1341d741e2baf4))

*  CheckpointSuite no longer kw_only — rjdbcm &lt;ozi.project@outlook.com&gt;
([`2804a02`](https://github.com/OZI-Project/OZI/commit/2804a020be2e7481207b8490d636de768354da11))


### ✏️ Corrected Typos

*  remove Any — rjdbcm &lt;ozi.project@outlook.com&gt;
([`c8156ec`](https://github.com/OZI-Project/OZI/commit/c8156ec2549a4c3edb9602f0cee00dc53611fdee))


### Other


* 🚨 Type ignore ozi.spec.base.Default. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`d2804df`](https://github.com/OZI-Project/OZI/commit/d2804dfdb6ee4bbaec49e7123c13033c5af9eb73))

* 🚨 Fix empty list guard. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`fdccaae`](https://github.com/OZI-Project/OZI/commit/fdccaae2278a30beed5589263c98e14019667e9f))

* 📝 add some spec metadata to versions — rjdbcm &lt;ozi.project@outlook.com&gt;
([`13f37ac`](https://github.com/OZI-Project/OZI/commit/13f37ace212ef86fc0e39714bc1475b9652daf8d))

* 🚨 clean up import guards — rjdbcm &lt;ozi.project@outlook.com&gt;
([`cc78500`](https://github.com/OZI-Project/OZI/commit/cc78500977a5be2b77ba3fab7788b2c42dbfb8ab))

* :doc:🚨 refactor ozi.spec.base.Default

add iter method
help in Field metadata
improved docstring for asdict
([`66408f5`](https://github.com/OZI-Project/OZI/commit/66408f510814e98ed6b4e7c8546c0ab79cc40d91))

* 🚨 moved import guards to end of imports — rjdbcm &lt;ozi.project@outlook.com&gt;
([`791fcf6`](https://github.com/OZI-Project/OZI/commit/791fcf6a82a3e9476f0770ea1626c9bb89dddce4))

## 1.11.1 (2024-06-07)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/publish from 0.1.4 to 0.1.5

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.4 to 0.1.5.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/132db35a4d8eaec96886eecc50034f3c3db8bc45...edb7e48d4196153b8dabddb970405495e1ff2092)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`f39ec90`](https://github.com/OZI-Project/OZI/commit/f39ec905bc49c9b5e18aac0fe2df35e617ee7b57))

*  Bump OZI-Project/draft from 0.3.0 to 0.3.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.0 to 0.3.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/b1b9f3b412ed16a45dfe7c6f60ea8d6fbae97630...f136e6eb55507553aee04e92455cc2dc279583fc)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`ab9d266`](https://github.com/OZI-Project/OZI/commit/ab9d266bd9e030a65d48aeea40a6d7cc456c7af4))

*  Bump actions/dependency-review-action from 4.3.2 to 4.3.3

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.3.2 to 4.3.3.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/0c155c5e8556a497adf53f2c18edabf945ed8e70...72eb03d02c7872a771aacd928f3123ac62ad6d3a)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`58481c6`](https://github.com/OZI-Project/OZI/commit/58481c6e2d9583beffb8d7cecef2f2458e0a4dab))

*  Bump github/codeql-action from 3.25.7 to 3.25.8

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.7 to 3.25.8.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/f079b8493333aace61c81488f8bd40919487bd9f...2e230e8fe0ad3a14a340ad0815ddb96d599d2aff)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`db3b62d`](https://github.com/OZI-Project/OZI/commit/db3b62da0a2b93ac289a8dfb38e3fb3356f00f78))

*  Bump github/codeql-action from 3.25.6 to 3.25.7

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.6 to 3.25.7.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/9fdb3e49720b44c48891d036bb502feb25684276...f079b8493333aace61c81488f8bd40919487bd9f)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`8ff6ee3`](https://github.com/OZI-Project/OZI/commit/8ff6ee334165b1b55702b922a09ab8ae91172a1d))


### 🔨 Updated Scripts

*  CommentPatterns spec class is now public. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`d0d5035`](https://github.com/OZI-Project/OZI/commit/d0d5035a34fe011ce9b2f34a14a866e070ba90a8))


### 📌 Pinned Dependencies

*  OZI-Project/draft 0.3.1 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`7d1b5f3`](https://github.com/OZI-Project/OZI/commit/7d1b5f3e690494368407c1ef5defff5aca8a68fb))

*  OZI-Project/publish 0.1.5 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`1d15f59`](https://github.com/OZI-Project/OZI/commit/1d15f59fd6add19139b4c74f8b926f2e731cf143))

## 1.11.0 (2024-05-30)


### ⬆️ Upgraded Dependencies

*  blastpipe~=2024.10.1 — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`4332d46`](https://github.com/OZI-Project/OZI/commit/4332d46aaa00f7264e19d3601451d7a1fc3329b2))


### 📌 Pinned Dependencies

*  blastpipe~=2024.10 — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`532f42a`](https://github.com/OZI-Project/OZI/commit/532f42a2abf2a4e62e0a9e12d1a01856232bc55b))


### ✨ Implemented Features

* 🐛 FIX Our Python distribution support keys are incorrect #620 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`1400beb`](https://github.com/OZI-Project/OZI/commit/1400beb06219e4cca5961460c3f6605322a5c927))

## 1.10.2 (2024-05-30)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/draft from 0.2.0 to 0.2.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.2.0 to 0.2.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/52700faa171c8b44e53834c4878e6cbca430b1d9...914c0f88bb59d105ed0fc061278442565bb6860c)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`ee6c27a`](https://github.com/OZI-Project/OZI/commit/ee6c27aa58e9362a1bb4993d6a598dd4ec777129))

*  Bump OZI-Project/publish from 0.1.3 to 0.1.4

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.3 to 0.1.4.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/f5d14bfb29fd5daa0fd3002a9c57f863e86ddf93...132db35a4d8eaec96886eecc50034f3c3db8bc45)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`18fb106`](https://github.com/OZI-Project/OZI/commit/18fb10681545764f55d4a73d4139970864649aa3))

## 1.10.1 (2024-05-27)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/publish from 0.1.2 to 0.1.3

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.2 to 0.1.3.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/e0a606616e2ff69a1b564f151f1061601683668f...f5d14bfb29fd5daa0fd3002a9c57f863e86ddf93)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`6823b84`](https://github.com/OZI-Project/OZI/commit/6823b84627acfb2511685963846ceb3a079d6a4c))


### 📌 Pinned Dependencies

*  OZI-Project/publish@0.1.3 in spec — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`1b00586`](https://github.com/OZI-Project/OZI/commit/1b005868ab6eb32f6f131db6f09a49063b3bfcba))

## 1.10.0 (2024-05-27)


### ⬆️ Upgraded Dependencies

*  OZI-Project/checkpoint-0.4.0

Now accepting args for tox posargs. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`eb1cee9`](https://github.com/OZI-Project/OZI/commit/eb1cee92ca8ac576cca50a28f85fded3bf820dda))


### 🔨 Updated Scripts

*  accept posargs to checkpoint suites — rjdbcm &lt;ozi.project@outlook.com&gt;
([`912e394`](https://github.com/OZI-Project/OZI/commit/912e394cfa2f969f4b49ee5fea1e019063544190))

*  Display spec version of OZI when tag history not found.

This mainly applies when OZI is invoked as a wrapdb or subproject. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`976d574`](https://github.com/OZI-Project/OZI/commit/976d574ad7d2c733656ce86e5aa170cbc07f134e))

*  remove docs setup, clarify meson config messages. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`bbfb9c5`](https://github.com/OZI-Project/OZI/commit/bbfb9c5bc175fb60b07984231170f97fd61e83b9))


### ✨ Implemented Features

* 📌 blastpipe~=2024.9.3 — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`2a3c4d1`](https://github.com/OZI-Project/OZI/commit/2a3c4d1565a243f610ba81def6271ba443399dcb))


### 🔨 Updated Configuration

*  bump checkpoint in spec and add 1.10 branch pattern — rjdbcm &lt;ozi.project@outlook.com&gt;
([`7dfca03`](https://github.com/OZI-Project/OZI/commit/7dfca03a5166961bee35cedaa545479ee2f1829a))

*  configure step options for each checkpoint utility.

Uses ``config-args-`` prefix, does not include plugins, as these share a requirements input with their parent module. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`3f509e6`](https://github.com/OZI-Project/OZI/commit/3f509e66c3d38f0a714a4afa1aea2ba1f7af9311))

*  add install options for each checkpoint command. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`223ad2f`](https://github.com/OZI-Project/OZI/commit/223ad2fabd420a36d8f57343b1cffb4a4641fe81))

## 1.9.10 (2024-05-23)


### 🐛 Fixed Bugs

*  fix bad default value for ``--check-license-expr``
([`d5a7609`](https://github.com/OZI-Project/OZI/commit/d5a7609c080a28881de6d33944b158df793a17bd))

## 1.9.9 (2024-05-23)


### 🐛 Fixed Bugs

* 📝 fix no cover showing up in docs
([`231625c`](https://github.com/OZI-Project/OZI/commit/231625c85234be3a212dbaeee7b55ea0a78ef767))

## 1.9.8 (2024-05-23)


### 🐛 Fixed Bugs

*  fix ``--check-license-expression`` wasnt accepting args. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`f858e41`](https://github.com/OZI-Project/OZI/commit/f858e41e6243aa33ab7a0a450b93672df9562f20))


### Other


* no cover — rjdbcm &lt;ozi.project@outlook.com&gt;
([`28a9602`](https://github.com/OZI-Project/OZI/commit/28a9602f8fae2a65d081fbca9337ce71b47ac659))

## 1.9.7 (2024-05-23)


### 🐛 Fixed Bugs

* 📝 fix ``ozi-new project`` parser docs — rjdbcm &lt;ozi.project@outlook.com&gt;
([`fdcd0cd`](https://github.com/OZI-Project/OZI/commit/fdcd0cd8d65806be5be415593af1c81195c368de))

## 1.9.6 (2024-05-23)


### 🐛 Fixed Bugs

* 📝 Clean up documentation of CLI. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`a5aa0c2`](https://github.com/OZI-Project/OZI/commit/a5aa0c20fd51509e7ee67003f7096785413aea8a))


### Other


* flake8 ignore long format string
([`a3ff071`](https://github.com/OZI-Project/OZI/commit/a3ff071b034646d5c30a66bc24a94b69e344038b))

## 1.9.5 (2024-05-23)


### 🐛 Fixed Bugs

*  clean up CLI help and options printout. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`ede0289`](https://github.com/OZI-Project/OZI/commit/ede0289fd95dd70bb349a985d35a5e4bbaf4d4cb))

## 1.9.4 (2024-05-23)


### 🔨 Updated Scripts

* 📝 add LICENSE_EXPR metavar and doc — rjdbcm &lt;ozi.project@outlook.com&gt;
([`1614d31`](https://github.com/OZI-Project/OZI/commit/1614d310bc660ed62097389febb180a2ac5c53f8))

* 📝 fix ``--list-available`` doc presentation. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`1c48693`](https://github.com/OZI-Project/OZI/commit/1c48693cbb1e39a28d3aafcc919f5ad8cfddc59a))

## 1.9.3 (2024-05-22)


### 🐛 Fixed Bugs

*  revert change to list-available arg. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`49afaaf`](https://github.com/OZI-Project/OZI/commit/49afaaf1ba03fdb878ef4a33a9880071176b2169))

## 1.9.2 (2024-05-22)


### 🔨 Updated Scripts

* 📝 update docstrings and CLI helps. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`adb9487`](https://github.com/OZI-Project/OZI/commit/adb948737e942d6c954e4896f2e0e9bef7192908))

## 1.9.1 (2024-05-22)


### 📌 Pinned Dependencies

*  blastpipe~=2024.9.1 — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`327ca80`](https://github.com/OZI-Project/OZI/commit/327ca800aa85921aa5bb8b32a09179846183e224))


### Other


* 


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`62af563`](https://github.com/OZI-Project/OZI/commit/62af563627568d412ef4a1ef01899b1da0487b89))

## 1.9.0 (2024-05-21)


### 📌 Pinned Dependencies

*  Update ci.py - Release 0.5.10  — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`d827e33`](https://github.com/OZI-Project/OZI/commit/d827e33cd45396c97efd62585ca7e3239239b05f))

*  blastpipe~=2024.9 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`00051ee`](https://github.com/OZI-Project/OZI/commit/00051ee3461002fc0432fe91529069316212dc32))


### ✨ Implemented Features

*  Use oziproject.dev API workflows. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`967c5d2`](https://github.com/OZI-Project/OZI/commit/967c5d2d10bc1f0bfb3b16b1f926d5e51e6a5b7d))


### 🔨 Updated Configuration

*  add 1.9 branch pattern — rjdbcm &lt;ozi.project@outlook.com&gt;
([`ff90526`](https://github.com/OZI-Project/OZI/commit/ff905266ca2b558b071849c218edc32ffa90f1d8))

* 👷 Update dev-workflow.yml — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`a4cf2cf`](https://github.com/OZI-Project/OZI/commit/a4cf2cfcbfff42e1e57c112d2a51a3578a0080cb))


### Other


* Update dist-workflow.yml - release 0.5.10 — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`828b086`](https://github.com/OZI-Project/OZI/commit/828b086498838db0686a532a37d1b5232f56f8b5))

* retry release — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`b7c73b5`](https://github.com/OZI-Project/OZI/commit/b7c73b541123c82bc2f5dd95d4d6f94385433232))

* Update dist-workflow.yml allow objects.githubusercontent.com:443 — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`20e6a5b`](https://github.com/OZI-Project/OZI/commit/20e6a5bababb0806fcd51fc5b8adbf4a5caa6ce1))

* Update dist-workflow.yml - allow API endpoint — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`a488a66`](https://github.com/OZI-Project/OZI/commit/a488a66a359e0e73da4a5a614032253dadf983f7))

* Update dist-workflow.yml — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`8649788`](https://github.com/OZI-Project/OZI/commit/8649788d9fc20ba203da61fea22ad87a7ec94f50))

* 
updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`7ec3682`](https://github.com/OZI-Project/OZI/commit/7ec36822d1deeb25835e157b28a2a273e00656db))

* 
updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`0a8d598`](https://github.com/OZI-Project/OZI/commit/0a8d59830717469c99e479a350aecbe3304cafa5))

## 1.8.5 (2024-05-21)

## 1.8.4 (2024-05-20)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/publish from 0.1.1 to 0.1.2

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.1 to 0.1.2.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/87aae4bed7ea3ab8b864689945200ecd71ecc29f...e0a606616e2ff69a1b564f151f1061601683668f)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`a7903eb`](https://github.com/OZI-Project/OZI/commit/a7903eb30aec3bc1afd7a90b3f641bc59a30945c))

*  Bump OZI-Project/release from 0.4.0 to 0.4.1

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.4.0 to 0.4.1.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/8b5e46e9d8899289f676ca2b432a63fe2faa93f9...033e98adfa7086d1b1273bcc80b0576297e733bd)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`04a849d`](https://github.com/OZI-Project/OZI/commit/04a849d5ffc200d5f5f609dcee64fcde0f516a9d))


### Other


* 


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`c3fe678`](https://github.com/OZI-Project/OZI/commit/c3fe678ea94dd230d7c4a74c173919b4ffc1970d))

* 


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`b5f2ce9`](https://github.com/OZI-Project/OZI/commit/b5f2ce9dee8273df8fb78225f2a0fae4cc27d616))

## 1.8.3 (2024-05-19)


### 🐛 Fixed Bugs

*  Shorten reprs of pkg and project spec. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`0dc3f21`](https://github.com/OZI-Project/OZI/commit/0dc3f21e2a61d02ca7af9ffdbf60644dfa4ac511))

## 1.8.2 (2024-05-19)


### 🐛 Fixed Bugs

*  fix unimplemented repr in ``ozi.spec.base.Default`` — rjdbcm &lt;ozi.project@outlook.com&gt;
([`e7791d0`](https://github.com/OZI-Project/OZI/commit/e7791d017cf770d47fe847bc8d949d634e81ce95))

## 1.8.1 (2024-05-18)


### 🚸 Improved Usability

*  truncated ``ozi.spec`` repr.
([`a5a3bd6`](https://github.com/OZI-Project/OZI/commit/a5a3bd605c33aad9c0431ff1ac983f8e32357634))

## 1.8.0 (2024-05-18)


### ⬆️ Upgraded Dependencies

* 📌 blastpipe~=2024.8 — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`d356293`](https://github.com/OZI-Project/OZI/commit/d3562932378ce2c11ef72e9e01e414dfab0f6db3))

*  OZI-Project/checkpoint 0.2.0 — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`1cc5620`](https://github.com/OZI-Project/OZI/commit/1cc5620f3bea66a56247a7ad61f9f854926b0286))


### 📌 Pinned Dependencies

*  Update ozi/spec/ci.py - checkpoint 0.2.0 — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`48b4cf6`](https://github.com/OZI-Project/OZI/commit/48b4cf699fd69af3ae5d152beeb80a43184352a2))


### ✨ Implemented Features

*  Update README.rst for 1.8 — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`31f26dd`](https://github.com/OZI-Project/OZI/commit/31f26dd17f6ed28adf0250e9f4725a93696742d4))


### Other


* Update README.rst — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`a1fd7f8`](https://github.com/OZI-Project/OZI/commit/a1fd7f828180302789e242564c5b34bc7df7244b))

* Feature/1.8 pipx integration (#540)

* ✨ Enable pipx isolation of apps.
* 🔨 Update spec files.
* ⬆️ OZI Spec v0.4
* 🔧 add 1.8 release branch pattern.

The following are no longer in ``meson.options:module-only``:
* sigstore
* Flake8-pyproject
* coverage
* flake8
* bandit
* black
* isort
* pyright
* mypy



Signed-off-by: rjdbcm &lt;ozi.project@outlook.com&gt;
([`50d4509`](https://github.com/OZI-Project/OZI/commit/50d450935d3333a58c98c8dbf19d594620adce36))

* Update dist-workflow.yml checkpoint 0.2.0 — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`a155b06`](https://github.com/OZI-Project/OZI/commit/a155b0627a82cf6d9868b13b74f7697568cbbfd5))

## 1.7.4 (2024-05-18)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/draft from 0.1.1 to 0.1.2

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.1.1 to 0.1.2.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/7fb25933b941dc9531abb0809d0be0c79404b351...574ec018b98bb323c079a826b54247c78cc4abac)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`b285fdc`](https://github.com/OZI-Project/OZI/commit/b285fdc6eb8628e49e498da3ee2b6a110ef32b88))

*  Bump actions/checkout from 4.1.5 to 4.1.6

Bumps [actions/checkout](https://github.com/actions/checkout) from 4.1.5 to 4.1.6.
- [Release notes](https://github.com/actions/checkout/releases)
- [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
- [Commits](https://github.com/actions/checkout/compare/44c2b7a8a4ea60a981eaca3cf939b5f4305c123b...a5ac7e51b41094c92402da3b24376905380afc29)


updated-dependencies:
- dependency-name: actions/checkout
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`f6daa93`](https://github.com/OZI-Project/OZI/commit/f6daa9357359255cbc1b53076448bb95c6dc2048))

## 1.7.3 (2024-05-16)


### 🐛 Fixed Bugs

*  Fix entrypoint arg conflict.

``ozi --license-expression`` is now ``ozi --check-license-expr``
([`e13d0ed`](https://github.com/OZI-Project/OZI/commit/e13d0eddb98513b6646e20c8cb10f2ed2bfec6b2))

## 1.7.2 (2024-05-16)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.25.4 to 3.25.5

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.4 to 3.25.5.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/ccf74c947955fd1cf117aef6a0e4e66191ef6f61...b7cec7526559c32f1616476ff32d17ba4c59b2d6)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`601250f`](https://github.com/OZI-Project/OZI/commit/601250f26f2ad97f20e9fb8ad8c718dfca60e1c3))


### 🐛 Fixed Bugs

*  fix imports.
([`bf0ac1f`](https://github.com/OZI-Project/OZI/commit/bf0ac1f6c577eb1976d1de4927c2d89e2dcd3170))

*  remove offset argv in ``ozi-new`` — rjdbcm &lt;ozi.project@outlook.com&gt;
([`a27b2a5`](https://github.com/OZI-Project/OZI/commit/a27b2a5db40454fc8d212f9aa1f8070f62914bc0))

## 1.7.1 (2024-05-14)


### 📌 Pinned Dependencies

*  Spec version set to 0.3 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`d007b1e`](https://github.com/OZI-Project/OZI/commit/d007b1e55cbf68488ca97f4594f03beec2f39a04))

## 1.7.0 (2024-05-14)


### Other


* Update pyproject.toml — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`2e4d278`](https://github.com/OZI-Project/OZI/commit/2e4d2781177aead20e41ea24cd9586e30113f361))

## 1.6.5 (2024-05-13)


### 🐛 Fixed Bugs

*  Fix bug introduced in ``ozi-fix`` 1.6.4.

missing target positional argument. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`335558d`](https://github.com/OZI-Project/OZI/commit/335558da5eda61d230990d4429d816455372e143))


### ✨ Implemented Features

*  markdown and plaintext readmes. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`bf5f5ac`](https://github.com/OZI-Project/OZI/commit/bf5f5ac5c4824b82be8b29b496025b28a6b3ffce))

## 1.6.4 (2024-05-13)


### 🐛 Fixed Bugs

*  Parsers default to target the current working dir. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`7628281`](https://github.com/OZI-Project/OZI/commit/7628281ade6849d747f797ad7e29816c0fa7561a))


### Other


* run black
([`18f2ad8`](https://github.com/OZI-Project/OZI/commit/18f2ad80aecb5a7209ba9499673ceae6e1bfb978))

* run black — rjdbcm &lt;ozi.project@outlook.com&gt;
([`344ad5d`](https://github.com/OZI-Project/OZI/commit/344ad5da25b74f6b7b5edfa6077a1149ded15440))

## 1.6.3 (2024-05-13)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/draft from 0.1.0 to 0.1.1

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.1.0 to 0.1.1.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/12b9a4f0d4e25ff5466bf2b0486d11aa4f3bf30d...7fb25933b941dc9531abb0809d0be0c79404b351)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`c7d8ba4`](https://github.com/OZI-Project/OZI/commit/c7d8ba484043458621d0696a4010f2e249410fae))


### Other


* Update ci.py — Eden Ross Duff, MSc &lt;ozi.project@outlook.com&gt;
([`7e71362`](https://github.com/OZI-Project/OZI/commit/7e71362bba2fbf422a9a7f29954a027fd506cd0c))

## 1.6.2 (2024-05-13)


### ✏️ Corrected Typos

*  fix version pin
([`ed5e623`](https://github.com/OZI-Project/OZI/commit/ed5e6230852b419e5a33841eda212c99c8839413))

* 📌 add ``packaging`` as dependency. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`1978a4c`](https://github.com/OZI-Project/OZI/commit/1978a4cf21eeb0b44643f609f3a382c5e4a550ec))

## 1.6.1 (2024-05-12)


### 💬


*  clean up package maintainer names. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`286cfea`](https://github.com/OZI-Project/OZI/commit/286cfea531180021b788072ae55e330a9885d965))


### Other


* Update scorecard.yml — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`efd87cd`](https://github.com/OZI-Project/OZI/commit/efd87cdfd4401b03dd6d01ece19279ce02574507))

## 1.6.0 (2024-05-10)

## 1.5.1 (2024-05-10)


### ⬆️ Upgraded Dependencies

*  Update blastpipe~=2024.6.3 — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`45d855c`](https://github.com/OZI-Project/OZI/commit/45d855ca84f9c68b38e80d530c66d2ae3021fc31))

*  Bump ossf/scorecard-action from 2.3.1 to 2.3.3

Bumps [ossf/scorecard-action](https://github.com/ossf/scorecard-action) from 2.3.1 to 2.3.3.
- [Release notes](https://github.com/ossf/scorecard-action/releases)
- [Changelog](https://github.com/ossf/scorecard-action/blob/main/RELEASE.md)
- [Commits](https://github.com/ossf/scorecard-action/compare/0864cf19026789058feabb7e87baa5f140aac736...dc50aa9510b46c811795eb24b2f1ba02a914e534)


updated-dependencies:
- dependency-name: ossf/scorecard-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`a081ae5`](https://github.com/OZI-Project/OZI/commit/a081ae5d80107471828f40c0486c7a6df181ee89))


### ✨ Implemented Features

*  update spec version to 0.2 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`b9decce`](https://github.com/OZI-Project/OZI/commit/b9decce98202932032ddb937263450bb462d52c3))


### Other


* 📝 Update pyproject.toml add branch release pattern. — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`e27296a`](https://github.com/OZI-Project/OZI/commit/e27296ac8e6cbb2152dd121ebb817392e20f19c7))

## 1.5.0 (2024-05-09)


### 🔨 Updated Configuration

*  add 1.5 release branch group — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`fa09315`](https://github.com/OZI-Project/OZI/commit/fa09315597531d789b1a364e35bdb3885e20e301))

## 1.4.3 (2024-05-08)


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.25.3 to 3.25.4

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.3 to 3.25.4.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/d39d31e687223d841ef683f52467bd88e9b21c14...ccf74c947955fd1cf117aef6a0e4e66191ef6f61)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`8e83edb`](https://github.com/OZI-Project/OZI/commit/8e83edbd2c514fa57bb9cccf51730f9eebc6a6e8))

*  Bump OZI-Project workflow actions

* OZI-Project/checkpoint 0.1.6
* OZI-Project/release 0.3.2
* OZI-Project/release 0.1.1 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`fb19e5a`](https://github.com/OZI-Project/OZI/commit/fb19e5a1140d3a8fc617d7d3cdca0b8880e1e465))

*  Bump actions/checkout from 4.1.4 to 4.1.5

Bumps [actions/checkout](https://github.com/actions/checkout) from 4.1.4 to 4.1.5.
- [Release notes](https://github.com/actions/checkout/releases)
- [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
- [Commits](https://github.com/actions/checkout/compare/0ad4b8fadaa221de15dcec353f45205ec38ea70b...44c2b7a8a4ea60a981eaca3cf939b5f4305c123b)


updated-dependencies:
- dependency-name: actions/checkout
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`971c548`](https://github.com/OZI-Project/OZI/commit/971c5483215457df5c70d99bcf34bb7513622882))


### 🔨 Updated Scripts

*  clean up jinja2 import. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`b6e6f50`](https://github.com/OZI-Project/OZI/commit/b6e6f505c8221bcab9e2f80ea44de65505cdc6ae))


### ✏️ Corrected Typos

*  fix docstring raw html escapes — rjdbcm &lt;ozi.project@outlook.com&gt;
([`ef63113`](https://github.com/OZI-Project/OZI/commit/ef63113a8f60366fff120b28cf1a2e9f3382183f))

*  missing ``from __future__ import annotations`` — rjdbcm &lt;ozi.project@outlook.com&gt;
([`508291a`](https://github.com/OZI-Project/OZI/commit/508291ade1880fdd0e96aeefb78d43265126f600))

*  fix RuntimeWarning that should be FutureWarning — rjdbcm &lt;ozi.project@outlook.com&gt;
([`0f23f31`](https://github.com/OZI-Project/OZI/commit/0f23f3121e2434cbe509b1230735c8a6dba56cd9))


### 📌 Pinned Dependencies

*  Set blastpipe 2024.5 as the compatible version. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`1b33b6c`](https://github.com/OZI-Project/OZI/commit/1b33b6c3a58e9069b83a1ac94dc46c541a68aead))


### ✨ Implemented Features

*   Add cython extensions with ``ozi-fix``

Also add ``--[no-]enable-cython`` to ``ozi-new``.
⬆️ blastpipe 2024.5 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`407db9b`](https://github.com/OZI-Project/OZI/commit/407db9b1abc53b30e9aa73ab589a2e5b0056f726))

## 1.4.2 (2024-05-05)


### 🐛 Fixed Bugs

*  correct deprecated Python warnings.

User-facing deprecation warnings should always use FutureWarning. — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`df2de03`](https://github.com/OZI-Project/OZI/commit/df2de0354a546f6a092c277a479b2e0fa6b2edb5))

## 1.4.1 (2024-05-05)


### 🐛 Fixed Bugs

*  Update ozi.spec.python

PendingDeprecationWarning 52 weeks prior to python end-of-life
DeprecationWarning instead of RuntimeError if python end-of-life reached. — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`b2ffa99`](https://github.com/OZI-Project/OZI/commit/b2ffa995cd3b907d5a9db8e4606f01db3c09ca56))


### Other


* Update ci.py — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`54917ec`](https://github.com/OZI-Project/OZI/commit/54917eca88d25e2e2ecc567cbd50965407c86689))

* Update pyproject.toml — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`4dfc574`](https://github.com/OZI-Project/OZI/commit/4dfc5749b8b59a112a498c6aa0385fe1b6e6ae66))

## 1.4.0 (2024-05-04)


### Other


* Update pyproject.toml - add 1.4 branch — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`40954c3`](https://github.com/OZI-Project/OZI/commit/40954c3fa1ed1a850eb5b1d18874b1dfe46cae9d))

## 1.3.3 (2024-05-04)

## 1.3.2 (2024-05-03)


### ⬆️ Upgraded Dependencies

*  Update requirements.in, bump blastpipe. — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`effa8a7`](https://github.com/OZI-Project/OZI/commit/effa8a7f7018d64200888e4351f85b25bda44b09))

*  Update blastpipe pin to 2024.4.0 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`bfea6bf`](https://github.com/OZI-Project/OZI/commit/bfea6bf78717dcc41ed8e96d4333c792d0a061dd))


### 🐛 Fixed Bugs

*  Update meson.build - dont build requirements during bootstrap. — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`33468ef`](https://github.com/OZI-Project/OZI/commit/33468ef723579b8505c47d2fb0dabfd55fb87688))

*  Update requirements.in — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`117fc93`](https://github.com/OZI-Project/OZI/commit/117fc939ca84bf0c038298d6282b046fb29f3d9e))

*  remove blastpipe wrapfile. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`d9bae28`](https://github.com/OZI-Project/OZI/commit/d9bae287ee6ad5a852cfb51a5636987ebb368d84))

*  Update meson.build fix blastpipe already being built. — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`7b5cf04`](https://github.com/OZI-Project/OZI/commit/7b5cf046d3bb6b76515273fc7fd16d0584e44698))

*  fix OZI.build — rjdbcm &lt;ozi.project@outlook.com&gt;
([`6f9cb08`](https://github.com/OZI-Project/OZI/commit/6f9cb08f9f6ce7622bea8ddf0ab0fdb02361240e))

*  Fix OZI.build — rjdbcm &lt;ozi.project@outlook.com&gt;
([`9cd8447`](https://github.com/OZI-Project/OZI/commit/9cd8447a4045c9688f79c18578fce36549613949))


### 📌 Pinned Dependencies

*  Update requirements.in - blastpipe 2024.4.3 — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`0d4a8a3`](https://github.com/OZI-Project/OZI/commit/0d4a8a34cfdf2761559c3435da4eeda6276311d4))


### ✨ Implemented Features

*  OZI-Project/release 0.3.0 and OZI.build 0.0.14 (#478)

* Update pyproject.toml - OZI.build 0.0.14

Signed-off-by: Eden Rose, MSc &lt;ozi.project@outlook.com&gt;

* Update ci.py

OZI-Project/OZI.build 0.0.14
OZI-Project/release 0.3.0

Signed-off-by: Eden Rose, MSc &lt;ozi.project@outlook.com&gt;

* Update dist-workflow.yml

Bump to 0.3.0 sha256:3067778a8ac4622c1075321b46b7a7333bea64a0

Signed-off-by: Eden Rose, MSc &lt;ozi.project@outlook.com&gt;



Signed-off-by: Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`83b8027`](https://github.com/OZI-Project/OZI/commit/83b80271f90a51b4b97914c4eb48bbde9b7f87c7))


### Other


* Update requirements.in - rollback blastpipe to stable version — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`49bfb81`](https://github.com/OZI-Project/OZI/commit/49bfb815003ffa930911686b296fe2874d664549))

## 1.3.1 (2024-05-03)


### ⬆️ Upgraded Dependencies

* 🐛 Bump OZI.build 0.0.12 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`4d24665`](https://github.com/OZI-Project/OZI/commit/4d24665dabab58f19119bae5c25581c98fdfe32c))


### 🐛 Fixed Bugs

*  OZI.build 0.0.11 fixes for in-situ metadata generation

* ⬆️ OZI.build 0.0.9 for correct wheel names.

Signed-off-by: rjdbcm &lt;ozi.project@outlook.com&gt;

* ⬆️ Fix ``pyproject.toml:tool.ozi-build.metadata`` rendering.

Also updates the blastpipe pin to ``&gt;=2024.4``

Signed-off-by: rjdbcm &lt;ozi.project@outlook.com&gt;

*  fix pin

Signed-off-by: rjdbcm &lt;ozi.project@outlook.com&gt;

* ⬆️ Fix OZI.build missing builddir in checkpoint runs.

Signed-off-by: rjdbcm &lt;ozi.project@outlook.com&gt;

* ⬆️ OZI.build 0.0.11 fixes for in-situ metadata generation.

Signed-off-by: rjdbcm &lt;ozi.project@outlook.com&gt;

*  revert blastpipe pin

Signed-off-by: rjdbcm &lt;ozi.project@outlook.com&gt;



Signed-off-by: rjdbcm &lt;ozi.project@outlook.com&gt;
Signed-off-by: Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`f800863`](https://github.com/OZI-Project/OZI/commit/f80086322ef1adee703fe006c313bec5690910c2))

## 1.3.0 (2024-05-03)


### ⬆️ Upgraded Dependencies

*  OZI.build 0.0.9 for correct wheel names. (#457) — rjdbcm &lt;ozi.project@outlook.com&gt;
([`adde41a`](https://github.com/OZI-Project/OZI/commit/adde41a9dd0eadcea050905799dc0509b3fb7e24))

*  Bump actions/dependency-review-action from 4.3.1 to 4.3.2

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.3.1 to 4.3.2.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/e58c696e52cac8e62d61cc21fda89565d71505d7...0c155c5e8556a497adf53f2c18edabf945ed8e70)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`7b83047`](https://github.com/OZI-Project/OZI/commit/7b830474618e3dd1778c8498ffbef75939ebd274))

*  OZI-Project/release 0.2.4 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`cefd702`](https://github.com/OZI-Project/OZI/commit/cefd702d81b1e0b9428d67b78c10a8cebcc1b3ef))

*  OZI-Project/release 0.2.2

* Update ci.py 

Signed-off-by: Eden Rose, MSc &lt;ozi.project@outlook.com&gt;

* Update dist-workflow.yml

Signed-off-by: Eden Rose, MSc &lt;ozi.project@outlook.com&gt;



Signed-off-by: Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`28a1e70`](https://github.com/OZI-Project/OZI/commit/28a1e70a41dfe62a94e124790ec34ba592c9d773))

*  release 0.2.1

* Update dist-workflow.yml - release 0.2.1

Signed-off-by: Eden Rose, MSc &lt;ozi.project@outlook.com&gt;

* Update ci.py - release 0.2.1

Signed-off-by: Eden Rose, MSc &lt;ozi.project@outlook.com&gt;



Signed-off-by: Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`eb56e91`](https://github.com/OZI-Project/OZI/commit/eb56e91c27c40b359674b29d744124c25eacf322))

*  OZI.build 0.0.7 in spec — rjdbcm &lt;ozi.project@outlook.com&gt;
([`1e3a51d`](https://github.com/OZI-Project/OZI/commit/1e3a51dfd7fc140e122a999ae92e642a84cea822))

*  OZI-Project/release 0.2.0 for OZI.build backend change. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`24e23ba`](https://github.com/OZI-Project/OZI/commit/24e23baf1d795ee265580c84c721d55b6d7f037f))

*  OZI.build 0.0.7 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`817265b`](https://github.com/OZI-Project/OZI/commit/817265bd093260eda4e6ad1136fd87552a2657b5))

*  OZI.build 0.0.6 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`958b39a`](https://github.com/OZI-Project/OZI/commit/958b39aad552d2bc91520c2320c9fa94a1df4c09))


### 🔨 Updated Scripts

*  unlink extant PKG-INFO during dist. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`7b99c62`](https://github.com/OZI-Project/OZI/commit/7b99c62023ab54f2c6b9da017f1cbdcce5f2f949))

*  remove monkey-patched setuptools_scm dist script.
([`0505516`](https://github.com/OZI-Project/OZI/commit/050551600633572a647e239ebcfcadd5904c1c7f))

*  auto pkg-info — rjdbcm &lt;ozi.project@outlook.com&gt;
([`dc0ee47`](https://github.com/OZI-Project/OZI/commit/dc0ee47ef9789fabadbd63fee08ba62093bf719b))

*  revert pkg-info move — rjdbcm &lt;ozi.project@outlook.com&gt;
([`ff8356f`](https://github.com/OZI-Project/OZI/commit/ff8356f4fab00fd9b632f4fae356c1c5632a94b7))

*  change metadata pkg-info-file — rjdbcm &lt;ozi.project@outlook.com&gt;
([`84a6b13`](https://github.com/OZI-Project/OZI/commit/84a6b13c8d8b86b925c0c014b6d863caf5c5df2e))

*  Implement OZI.build — rjdbcm &lt;ozi.project@outlook.com&gt;
([`7a25a87`](https://github.com/OZI-Project/OZI/commit/7a25a870cefee7ad5bf054c152bd81d59f177055))


### ✨ Implemented Features

*  Add 1.3 release group! — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`fd418e4`](https://github.com/OZI-Project/OZI/commit/fd418e4b7ca008b63f62da106f9f7d5bf020d80d))

*  OZI 1.3 — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`c957112`](https://github.com/OZI-Project/OZI/commit/c9571120ba6765801e8f0447f60af0b5cead88b3))


### Other


* OZI-Project/release 0.2.5 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`e3801f4`](https://github.com/OZI-Project/OZI/commit/e3801f4161facecbb31385c933bfd0e90dd7bb83))

* Update dist-workflow.yml — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`65b7b67`](https://github.com/OZI-Project/OZI/commit/65b7b672b70a5791fbc76807b1dbcc3ed3036961))

* Update ci.py — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`924cd7e`](https://github.com/OZI-Project/OZI/commit/924cd7ee3cbb700cb55d772b06a2a8752fb2abcd))

* use pkg-info-file — rjdbcm &lt;ozi.project@outlook.com&gt;
([`1f09610`](https://github.com/OZI-Project/OZI/commit/1f096107ab8818f5e7d72c181a41cf29971573a5))

## 1.2.2 (2024-04-30)


### ⬆️ Upgraded Dependencies

*  Bump step-security/harden-runner from 2.7.0 to 2.7.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.7.0 to 2.7.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/63c24ba6bd7ba022e95695ff85de572c04a18142...a4aa98b93cab29d9b1101a6143fb8bce00e2eac4)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`3184386`](https://github.com/OZI-Project/OZI/commit/3184386d8308b4604d6f6c832940045176ec1e2d))

*  Bump actions/dependency-review-action from 4.2.5 to 4.3.1

Bumps [actions/dependency-review-action](https://github.com/actions/dependency-review-action) from 4.2.5 to 4.3.1.
- [Release notes](https://github.com/actions/dependency-review-action/releases)
- [Commits](https://github.com/actions/dependency-review-action/compare/5bbc3ba658137598168acb2ab73b21c432dd411b...e58c696e52cac8e62d61cc21fda89565d71505d7)


updated-dependencies:
- dependency-name: actions/dependency-review-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`1f7e9f1`](https://github.com/OZI-Project/OZI/commit/1f7e9f199315405bc2a17af147c41047ace16aa3))


### Other


* 📝 update docstrings for 1.2 (#429) — rjdbcm &lt;ozi.project@outlook.com&gt;
([`d72f67c`](https://github.com/OZI-Project/OZI/commit/d72f67c298a0dee02ad6abc3006b875b3067b397))

## 1.2.1 (2024-04-28)


### ⬆️ Upgraded Dependencies

*  Bump OZI-Project/release 0.1.18 &gt; 0.1.17

*  Update dist-workflow.yml - release 0.1.18 &gt; 0.1.17

Signed-off-by: Eden Rose, MSc &lt;ozi.project@outlook.com&gt;

*  bump release to 0.1.18

Signed-off-by: Eden Rose, MSc &lt;ozi.project@outlook.com&gt;



Signed-off-by: Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`656c609`](https://github.com/OZI-Project/OZI/commit/656c609ec37886c31679b7be6de2a08d9a950c0b))

## 1.2.0 (2024-04-28)


### 📌 Pinned Dependencies

*  set blastpipe pin to 2024.2.6. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`7ed571c`](https://github.com/OZI-Project/OZI/commit/7ed571c12c8e8b91082cbf7044f0ce28a7d63090))


### ✨ Implemented Features

*  Reduce the overall repo size.

Move templates to the blastpipe repo.
Make blastpipe a dependency. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`cfd1234`](https://github.com/OZI-Project/OZI/commit/cfd123435aaf83b4be871c1e42ea99c183e87999))


### Other


* 🚨 add ``# pyright: ignore`` to blastpipe filter imports. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`580750b`](https://github.com/OZI-Project/OZI/commit/580750b20cbf62152d81e7c0c91e94084349feed))

* add 1.2 release branch pattern — rjdbcm &lt;ozi.project@outlook.com&gt;
([`7c78a1e`](https://github.com/OZI-Project/OZI/commit/7c78a1e4d8a76db1091851de9084af6a6f50ccd9))

## 1.1.6 (2024-04-27)


### ⚗️


* (``ozi.render.load_environment``): Add globals dict argument. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`eaac863`](https://github.com/OZI-Project/OZI/commit/eaac8633e08b2f345333e4a4bfdf0b350ce7966d))


### ⬆️ Upgraded Dependencies

*  Bump github/codeql-action from 3.25.2 to 3.25.3

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.2 to 3.25.3.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/8f596b4ae3cb3c588a5c46780b86dd53fef16c52...d39d31e687223d841ef683f52467bd88e9b21c14)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`e7888b0`](https://github.com/OZI-Project/OZI/commit/e7888b059f9223008680a7d9dfd28e01a07205ba))

*  Bump actions/checkout from 4.1.3 to 4.1.4

Bumps [actions/checkout](https://github.com/actions/checkout) from 4.1.3 to 4.1.4.
- [Release notes](https://github.com/actions/checkout/releases)
- [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
- [Commits](https://github.com/actions/checkout/compare/1d96c772d19495a3b5c517cd2bc0cb401ea0529f...0ad4b8fadaa221de15dcec353f45205ec38ea70b)


updated-dependencies:
- dependency-name: actions/checkout
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`41251c9`](https://github.com/OZI-Project/OZI/commit/41251c94d744593a3931d1d5acd70ac18f2838e5))


### 🐛 Fixed Bugs

*  exclude double quotes from fuzzer input. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`361a75a`](https://github.com/OZI-Project/OZI/commit/361a75a9e1b63dc6ad12b24cf85f9762a213c8a7))


### Other


* 🚨 run ``black -S tests`` — rjdbcm &lt;ozi.project@outlook.com&gt;
([`fdd8fe2`](https://github.com/OZI-Project/OZI/commit/fdd8fe2fdbe6b7941972efc33aa77ee1707dae5a))

## 1.1.5 (2024-04-24)


### ⬆️ Upgraded Dependencies

*  Bump release to 0.1.17 — Eden Rose, MSc &lt;ozi.project@outlook.com&gt;
([`eca9b71`](https://github.com/OZI-Project/OZI/commit/eca9b713ea773157c3912eca2fb4d87ff38d0ef5))

*  Bump OZI-Project/release from 0.1.16 to 0.1.17

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.1.16 to 0.1.17.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/cde80205350cc9bd7c00c042b788136b36bd1828...ceffb3c8beef212a5abaffeac486d67fb247381b)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`5bd1337`](https://github.com/OZI-Project/OZI/commit/5bd1337de8893888ea714f9d361a9d287d2caabc))


### 🔨 Updated Scripts

*  Correct pytest ``--cov=`` argument.

Use the normalized module name in the template. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`aaaa7c3`](https://github.com/OZI-Project/OZI/commit/aaaa7c30ecd16040224e0933bbef26d0ab45347e))

## 1.1.4 (2024-04-24)


### 🐛 Fixed Bugs

* 🔨 Fix pytest-args for coverage. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`1193781`](https://github.com/OZI-Project/OZI/commit/119378168e8e56096e05751b170fcd29a23e676b))

## 1.1.3 (2024-04-24)


### 🔨 Updated Scripts

*  retry release

Merge pull request #411 from OZI-Project/release/1.1
([`5eef90b`](https://github.com/OZI-Project/OZI/commit/5eef90b471611999873de5fca990e687823c1246))


### Other


* 🚨 Fix project template lint. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`e946042`](https://github.com/OZI-Project/OZI/commit/e9460422674d666cb62f314a6d5dced9004fdd93))

## 1.1.2 (2024-04-24)


### 🐛 Fixed Bugs

*  Fix failing project build. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`c87cbfd`](https://github.com/OZI-Project/OZI/commit/c87cbfd2219b46704324e22f16ca7bf8ddc93c2f))


### Other


* 🚨 no cover to_distribution. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`cb4faba`](https://github.com/OZI-Project/OZI/commit/cb4faba04318b956c75a656a882d48a8ddecf4c1))

* Only run checkpoints on PR — rjdbcm &lt;ozi.project@outlook.com&gt;
([`1c28263`](https://github.com/OZI-Project/OZI/commit/1c2826321397784873ac366777ff2df1dd039038))

## 1.1.1 (2024-04-24)


### 🐛 Fixed Bugs

*  Fix pyproject_config missing in root ``meson.build`` template. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`99b6528`](https://github.com/OZI-Project/OZI/commit/99b652818efae3f303897f27dcebb27d817574ec))

## 1.1.0 (2024-04-23)


### ⬆️ Upgraded Dependencies

*  Bump slsa-framework/slsa-github-generator

Bumps [slsa-framework/slsa-github-generator](https://github.com/slsa-framework/slsa-github-generator) from 1.10.0 to 2.0.0.
- [Release notes](https://github.com/slsa-framework/slsa-github-generator/releases)
- [Changelog](https://github.com/slsa-framework/slsa-github-generator/blob/main/CHANGELOG.md)
- [Commits](https://github.com/slsa-framework/slsa-github-generator/compare/v1.10.0...v2.0.0)


updated-dependencies:
- dependency-name: slsa-framework/slsa-github-generator
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] &lt;support@github.com&gt;
([`613e61e`](https://github.com/OZI-Project/OZI/commit/613e61ece9249db1d341d2ca3bd5ee9af4aa9032))

*  Bump OZI-Project/checkpoint from 0.1.4 to 0.1.5

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.1.4 to 0.1.5.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/8b7d897024b918d4bb4d44bbaec23a22f357182e...a6290f1edcd89a03dca8d123327e25f0c3bfc91c)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`d8b8bf4`](https://github.com/OZI-Project/OZI/commit/d8b8bf4d88e7727bc54ab5b07851233425d8bdf9))

*  Bump slsa-framework/slsa-github-generator

Bumps [slsa-framework/slsa-github-generator](https://github.com/slsa-framework/slsa-github-generator) from 1.10.0 to 2.0.0.
- [Release notes](https://github.com/slsa-framework/slsa-github-generator/releases)
- [Changelog](https://github.com/slsa-framework/slsa-github-generator/blob/main/CHANGELOG.md)
- [Commits](https://github.com/slsa-framework/slsa-github-generator/compare/v1.10.0...v2.0.0)


updated-dependencies:
- dependency-name: slsa-framework/slsa-github-generator
  dependency-type: direct:production
  update-type: version-update:semver-major
... — dependabot[bot] &lt;support@github.com&gt;
([`4c36d99`](https://github.com/OZI-Project/OZI/commit/4c36d99b912e91369441143dee2ce4031e9df5ca))

*  Bump github/codeql-action from 3.25.1 to 3.25.2

Bumps [github/codeql-action](https://github.com/github/codeql-action) from 3.25.1 to 3.25.2.
- [Release notes](https://github.com/github/codeql-action/releases)
- [Changelog](https://github.com/github/codeql-action/blob/main/CHANGELOG.md)
- [Commits](https://github.com/github/codeql-action/compare/c7f9125735019aa87cfc361530512d50ea439c71...8f596b4ae3cb3c588a5c46780b86dd53fef16c52)


updated-dependencies:
- dependency-name: github/codeql-action
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`e5c1cbe`](https://github.com/OZI-Project/OZI/commit/e5c1cbe8c62c08a43c224c0a8a5ccc444fd0d382))

*  Bump actions/upload-artifact from 4.3.2 to 4.3.3

Bumps [actions/upload-artifact](https://github.com/actions/upload-artifact) from 4.3.2 to 4.3.3.
- [Release notes](https://github.com/actions/upload-artifact/releases)
- [Commits](https://github.com/actions/upload-artifact/compare/1746f4ab65b179e0ea60a494b83293b640dd5bba...65462800fd760344b1a7b4382951275a0abb4808)


updated-dependencies:
- dependency-name: actions/upload-artifact
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`7ac5bb8`](https://github.com/OZI-Project/OZI/commit/7ac5bb8ab6e962f843538809d11bda1835a635f0))


### ✨ Implemented Features

*  Add 1.1 release branch group.
([`02ee683`](https://github.com/OZI-Project/OZI/commit/02ee683996ad5bbdf5b8289f490f9ce7bef34f13))

*  Alpha release/1.1

Release/1.0
([`2caf7b7`](https://github.com/OZI-Project/OZI/commit/2caf7b7650a911ab299f3e5997f5034362ad11fd))

*  SLSA provenance builder updated in template.

2.0.0&gt;1.10.0 — rjdbcm &lt;ozi.project@outlook.com&gt;
([`8235263`](https://github.com/OZI-Project/OZI/commit/8235263028a1b0ff389cbedaf316597ff609c83b))

## 1.0.0 (2024-04-22)


### ⬆️ Upgraded Dependencies

*  Merge pull request #388 from OZI-Project/main
([`4b7d4c4`](https://github.com/OZI-Project/OZI/commit/4b7d4c427fec29794a71229872ff84359f2ce4fa))


### 🐛 Fixed Bugs

*  fix version bump. — rjdbcm &lt;ozi.project@outlook.com&gt;
([`e518299`](https://github.com/OZI-Project/OZI/commit/e518299b62831f3674aecb5eda9e671f3de87aee))
